Class: Plaid::Account

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/account.rb

Overview

A single account at a financial institution.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_id:, balances:, mask:, name:, official_name:, type:, subtype:, verification_status: SKIP, additional_properties: nil) ⇒ Account

Returns a new instance of Account.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/plaid/models/account.rb', line 116

def initialize(account_id:, balances:, mask:, name:, official_name:, type:,
               subtype:, verification_status: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_id = 
  @balances = balances
  @mask = mask
  @name = name
  @official_name = official_name
  @type = type
  @subtype = subtype
  @verification_status = verification_status unless verification_status == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Plaid’s unique identifier for the account. This value will not change unless Plaid can’t reconcile the account with the data returned by the financial institution. This may occur, for example, when the name of the account changes. If this happens a new ‘account_id` will be assigned to the account. The `account_id` can also change if the `access_token` is deleted and the same credentials that were used to generate that `access_token` are used to generate a new `access_token` on a later date. In that case, the new `account_id` will be different from the old `account_id`. If an account with a specific `account_id` disappears instead of changing, the account is likely closed. Closed accounts are not returned by the Plaid API. Like all Plaid identifiers, the `account_id` is case sensitive.

Returns:

  • (String)


26
27
28
# File 'lib/plaid/models/account.rb', line 26

def 
  @account_id
end

#balancesAccountBalance

A set of fields describing the balance for an account. Balance information may be cached unless the balance object was returned by ‘/accounts/balance/get`.

Returns:



32
33
34
# File 'lib/plaid/models/account.rb', line 32

def balances
  @balances
end

#maskString

The last 2-4 alphanumeric characters of an account’s official account number. Note that the mask may be non-unique between an Item’s accounts, and it may also not match the mask that the bank displays to the user.

Returns:

  • (String)


38
39
40
# File 'lib/plaid/models/account.rb', line 38

def mask
  @mask
end

#nameString

The name of the account, either assigned by the user or by the financial institution itself

Returns:

  • (String)


43
44
45
# File 'lib/plaid/models/account.rb', line 43

def name
  @name
end

#official_nameString

The official name of the account as given by the financial institution

Returns:

  • (String)


47
48
49
# File 'lib/plaid/models/account.rb', line 47

def official_name
  @official_name
end

#subtypeAccountSubtype

See the [Account type schema](plaid.com/docs/api/accounts/#account-type-schema) for a full listing of account types and corresponding subtypes.

Returns:



66
67
68
# File 'lib/plaid/models/account.rb', line 66

def subtype
  @subtype
end

#typeAccountType

‘investment:` Investment account `credit:` Credit card `depository:` Depository account `loan:` Loan account `brokerage`: An investment account. Used for `/assets/` endpoints only; other endpoints use `investment`. `other:` Non-specified account type See the [Account type schema](plaid.com/docs/api/accounts#account-type-schema) for a full listing of account types and corresponding subtypes.

Returns:



60
61
62
# File 'lib/plaid/models/account.rb', line 60

def type
  @type
end

#verification_statusVerificationStatus4

The current verification status of an Auth Item initiated through Automated or Manual micro-deposits. Returned for Auth Items only. ‘pending_automatic_verification`: The Item is pending automatic verification `pending_manual_verification`: The Item is pending manual micro-deposit verification. Items remain in this state until the user successfully verifies the two amounts. `automatically_verified`: The Item has successfully been automatically verified `manually_verified`: The Item has successfully been manually verified `verification_expired`: Plaid was unable to automatically verify the deposit within 7 calendar days and will no longer attempt to validate the Item. Users may retry by submitting their information again through Link. `verification_failed`: The Item failed manual micro-deposit verification because the user exhausted all 3 verification attempts. Users may retry by submitting their information again through Link.

Returns:



85
86
87
# File 'lib/plaid/models/account.rb', line 85

def verification_status
  @verification_status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/plaid/models/account.rb', line 134

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_id') ? hash['account_id'] : nil
  balances = AccountBalance.from_hash(hash['balances']) if hash['balances']
  mask = hash.key?('mask') ? hash['mask'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  official_name = hash.key?('official_name') ? hash['official_name'] : nil
  type = hash.key?('type') ? hash['type'] : nil
  subtype = hash.key?('subtype') ? hash['subtype'] : nil
  verification_status =
    hash.key?('verification_status') ? hash['verification_status'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Account.new(account_id: ,
              balances: balances,
              mask: mask,
              name: name,
              official_name: official_name,
              type: type,
              subtype: subtype,
              verification_status: verification_status,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/plaid/models/account.rb', line 88

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_id'] = 'account_id'
  @_hash['balances'] = 'balances'
  @_hash['mask'] = 'mask'
  @_hash['name'] = 'name'
  @_hash['official_name'] = 'official_name'
  @_hash['type'] = 'type'
  @_hash['subtype'] = 'subtype'
  @_hash['verification_status'] = 'verification_status'
  @_hash
end

.nullablesObject

An array for nullable fields



109
110
111
112
113
114
# File 'lib/plaid/models/account.rb', line 109

def self.nullables
  %w[
    mask
    official_name
  ]
end

.optionalsObject

An array for optional fields



102
103
104
105
106
# File 'lib/plaid/models/account.rb', line 102

def self.optionals
  %w[
    verification_status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



177
178
179
180
181
182
183
# File 'lib/plaid/models/account.rb', line 177

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id.inspect}, balances: #{@balances.inspect}, mask:"\
  " #{@mask.inspect}, name: #{@name.inspect}, official_name: #{@official_name.inspect}, type:"\
  " #{@type.inspect}, subtype: #{@subtype.inspect}, verification_status:"\
  " #{@verification_status.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



168
169
170
171
172
173
174
# File 'lib/plaid/models/account.rb', line 168

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id}, balances: #{@balances}, mask: #{@mask}, name:"\
  " #{@name}, official_name: #{@official_name}, type: #{@type}, subtype: #{@subtype},"\
  " verification_status: #{@verification_status}, additional_properties:"\
  " #{@additional_properties}>"
end