Class: Plaid::ApplicationApi
- Defined in:
- lib/plaid/apis/application_api.rb
Overview
ApplicationApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#application_get(body) ⇒ ApiResponse
Allows financial institutions to retrieve information about Plaid clients for the purpose of building control-tower experiences description here.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Plaid::BaseApi
Instance Method Details
#application_get(body) ⇒ ApiResponse
Allows financial institutions to retrieve information about Plaid clients for the purpose of building control-tower experiences description here
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/plaid/apis/application_api.rb', line 14 def application_get(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/application/get', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ApplicationGetResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response.', ErrorErrorException)) .execute end |