Class: Plaid::AssetReportGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/asset_report_get_request.rb

Overview

AssetReportGetRequest defines the request schema for ‘/asset_report/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(asset_report_token:, client_id: SKIP, secret: SKIP, include_insights: SKIP, additional_properties: nil) ⇒ AssetReportGetRequest

Returns a new instance of AssetReportGetRequest.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/plaid/models/asset_report_get_request.rb', line 57

def initialize(asset_report_token:, client_id: SKIP, secret: SKIP,
               include_insights: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @asset_report_token = asset_report_token
  @include_insights = include_insights unless include_insights == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#asset_report_tokenString

A token that can be provided to endpoints such as ‘/asset_report/get` or `/asset_report/pdf/get` to fetch or update an Asset Report.

Returns:

  • (String)


26
27
28
# File 'lib/plaid/models/asset_report_get_request.rb', line 26

def asset_report_token
  @asset_report_token
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/plaid/models/asset_report_get_request.rb', line 16

def client_id
  @client_id
end

#include_insightsTrueClass | FalseClass

‘true` if you would like to retrieve the Asset Report with Insights, `false` otherwise. This field defaults to `false` if omitted.

Returns:

  • (TrueClass | FalseClass)


31
32
33
# File 'lib/plaid/models/asset_report_get_request.rb', line 31

def include_insights
  @include_insights
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/plaid/models/asset_report_get_request.rb', line 21

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/plaid/models/asset_report_get_request.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  asset_report_token =
    hash.key?('asset_report_token') ? hash['asset_report_token'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  include_insights =
    hash.key?('include_insights') ? hash['include_insights'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AssetReportGetRequest.new(asset_report_token: asset_report_token,
                            client_id: client_id,
                            secret: secret,
                            include_insights: include_insights,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
40
41
# File 'lib/plaid/models/asset_report_get_request.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['asset_report_token'] = 'asset_report_token'
  @_hash['include_insights'] = 'include_insights'
  @_hash
end

.nullablesObject

An array for nullable fields



53
54
55
# File 'lib/plaid/models/asset_report_get_request.rb', line 53

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
# File 'lib/plaid/models/asset_report_get_request.rb', line 44

def self.optionals
  %w[
    client_id
    secret
    include_insights
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
110
# File 'lib/plaid/models/asset_report_get_request.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " asset_report_token: #{@asset_report_token.inspect}, include_insights:"\
  " #{@include_insights.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
102
# File 'lib/plaid/models/asset_report_get_request.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, asset_report_token:"\
  " #{@asset_report_token}, include_insights: #{@include_insights}, additional_properties:"\
  " #{@additional_properties}>"
end