Class: Plaid::AssetsErrorWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/assets_error_webhook.rb

Overview

Fired when Asset Report generation has failed. The resulting ‘error` will have an `error_type` of `ASSET_REPORT_ERROR`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, error:, asset_report_id:, additional_properties: nil) ⇒ AssetsErrorWebhook

Returns a new instance of AssetsErrorWebhook.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/plaid/models/assets_error_webhook.rb', line 53

def initialize(webhook_type:, webhook_code:, error:, asset_report_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @error = error
  @asset_report_id = asset_report_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#asset_report_idString

The ID associated with the Asset Report.

Returns:

  • (String)


31
32
33
# File 'lib/plaid/models/assets_error_webhook.rb', line 31

def asset_report_id
  @asset_report_id
end

#errorError

We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`. In general, 200 HTTP codes correspond to success, 40X codes are for developer- or user-related failures, and 50X codes are for Plaid-related issues. Error fields will be `null` if no error has occurred.

Returns:



27
28
29
# File 'lib/plaid/models/assets_error_webhook.rb', line 27

def error
  @error
end

#webhook_codeString

‘ERROR`

Returns:

  • (String)


19
20
21
# File 'lib/plaid/models/assets_error_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘ASSETS`

Returns:

  • (String)


15
16
17
# File 'lib/plaid/models/assets_error_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/plaid/models/assets_error_webhook.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  error = Error.from_hash(hash['error']) if hash['error']
  asset_report_id =
    hash.key?('asset_report_id') ? hash['asset_report_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AssetsErrorWebhook.new(webhook_type: webhook_type,
                         webhook_code: webhook_code,
                         error: error,
                         asset_report_id: asset_report_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
40
41
# File 'lib/plaid/models/assets_error_webhook.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['error'] = 'error'
  @_hash['asset_report_id'] = 'asset_report_id'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/plaid/models/assets_error_webhook.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/plaid/models/assets_error_webhook.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
105
# File 'lib/plaid/models/assets_error_webhook.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, error: #{@error.inspect}, asset_report_id:"\
  " #{@asset_report_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
97
# File 'lib/plaid/models/assets_error_webhook.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\
  " #{@error}, asset_report_id: #{@asset_report_id}, additional_properties:"\
  " #{@additional_properties}>"
end