Class: Plaid::AuthSupportedMethods
- Defined in:
- lib/plaid/models/auth_supported_methods.rb
Overview
Metadata specifically related to which auth methods an institution supports.
Instance Attribute Summary collapse
-
#automated_micro_deposits ⇒ TrueClass | FalseClass
Indicates if automated microdeposits are supported.
-
#instant_auth ⇒ TrueClass | FalseClass
Indicates if instant auth is supported.
-
#instant_match ⇒ TrueClass | FalseClass
Indicates if instant match is supported.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(instant_auth:, instant_match:, automated_micro_deposits:, additional_properties: nil) ⇒ AuthSupportedMethods
constructor
A new instance of AuthSupportedMethods.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(instant_auth:, instant_match:, automated_micro_deposits:, additional_properties: nil) ⇒ AuthSupportedMethods
Returns a new instance of AuthSupportedMethods.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 43 def initialize(instant_auth:, instant_match:, automated_micro_deposits:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @instant_auth = instant_auth @instant_match = instant_match @automated_micro_deposits = automated_micro_deposits @additional_properties = additional_properties end |
Instance Attribute Details
#automated_micro_deposits ⇒ TrueClass | FalseClass
Indicates if automated microdeposits are supported.
22 23 24 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 22 def automated_micro_deposits @automated_micro_deposits end |
#instant_auth ⇒ TrueClass | FalseClass
Indicates if instant auth is supported.
14 15 16 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 14 def instant_auth @instant_auth end |
#instant_match ⇒ TrueClass | FalseClass
Indicates if instant match is supported.
18 19 20 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 18 def instant_match @instant_match end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. instant_auth = hash.key?('instant_auth') ? hash['instant_auth'] : nil instant_match = hash.key?('instant_match') ? hash['instant_match'] : nil automated_micro_deposits = hash.key?('automated_micro_deposits') ? hash['automated_micro_deposits'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AuthSupportedMethods.new(instant_auth: instant_auth, instant_match: instant_match, automated_micro_deposits: automated_micro_deposits, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['instant_auth'] = 'instant_auth' @_hash['instant_match'] = 'instant_match' @_hash['automated_micro_deposits'] = 'automated_micro_deposits' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 92 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} instant_auth: #{@instant_auth.inspect}, instant_match:"\ " #{@instant_match.inspect}, automated_micro_deposits: #{@automated_micro_deposits.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 84 |
# File 'lib/plaid/models/auth_supported_methods.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} instant_auth: #{@instant_auth}, instant_match: #{@instant_match},"\ " automated_micro_deposits: #{@automated_micro_deposits}, additional_properties:"\ " #{@additional_properties}>" end |