Class: Plaid::BankTransferMigrateAccountRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::BankTransferMigrateAccountRequest
- Defined in:
- lib/plaid/models/bank_transfer_migrate_account_request.rb
Overview
Defines the request schema for ‘/bank_transfer/migrate_account`
Instance Attribute Summary collapse
-
#account_number ⇒ String
The user’s account number.
-
#account_type ⇒ String
The type of the bank account (‘checking` or `savings`).
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#routing_number ⇒ String
The user’s routing number.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_number:, routing_number:, account_type:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BankTransferMigrateAccountRequest
constructor
A new instance of BankTransferMigrateAccountRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_number:, routing_number:, account_type:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BankTransferMigrateAccountRequest
Returns a new instance of BankTransferMigrateAccountRequest.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 59 def initialize(account_number:, routing_number:, account_type:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @account_number = account_number @routing_number = routing_number @account_type = account_type @additional_properties = additional_properties end |
Instance Attribute Details
#account_number ⇒ String
The user’s account number.
25 26 27 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 25 def account_number @account_number end |
#account_type ⇒ String
The type of the bank account (‘checking` or `savings`).
33 34 35 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 33 def account_type @account_type end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 16 def client_id @client_id end |
#routing_number ⇒ String
The user’s routing number.
29 30 31 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 29 def routing_number @routing_number end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_number = hash.key?('account_number') ? hash['account_number'] : nil routing_number = hash.key?('routing_number') ? hash['routing_number'] : nil account_type = hash.key?('account_type') ? hash['account_type'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankTransferMigrateAccountRequest.new(account_number: account_number, routing_number: routing_number, account_type: account_type, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
36 37 38 39 40 41 42 43 44 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 36 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['account_number'] = 'account_number' @_hash['routing_number'] = 'routing_number' @_hash['account_type'] = 'account_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
47 48 49 50 51 52 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 47 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " account_number: #{@account_number.inspect}, routing_number: #{@routing_number.inspect},"\ " account_type: #{@account_type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
102 103 104 105 106 107 |
# File 'lib/plaid/models/bank_transfer_migrate_account_request.rb', line 102 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, account_number:"\ " #{@account_number}, routing_number: #{@routing_number}, account_type: #{@account_type},"\ " additional_properties: #{@additional_properties}>" end |