Class: Plaid::DepositSwitchAltCreateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/deposit_switch_alt_create_response.rb

Overview

DepositSwitchAltCreateResponse defines the response schema for ‘/deposit_switch/alt/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(deposit_switch_id:, request_id:, additional_properties: nil) ⇒ DepositSwitchAltCreateResponse

Returns a new instance of DepositSwitchAltCreateResponse.



42
43
44
45
46
47
48
49
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 42

def initialize(deposit_switch_id:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @deposit_switch_id = deposit_switch_id
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#deposit_switch_idString

ID of the deposit switch. This ID is persisted throughout the lifetime of the deposit switch.

Returns:

  • (String)


16
17
18
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 16

def deposit_switch_id
  @deposit_switch_id
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


22
23
24
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 22

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  deposit_switch_id =
    hash.key?('deposit_switch_id') ? hash['deposit_switch_id'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DepositSwitchAltCreateResponse.new(deposit_switch_id: deposit_switch_id,
                                     request_id: request_id,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['deposit_switch_id'] = 'deposit_switch_id'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 33

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} deposit_switch_id: #{@deposit_switch_id.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/plaid/models/deposit_switch_alt_create_response.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} deposit_switch_id: #{@deposit_switch_id}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end