Class: Plaid::DepositSwitchCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::DepositSwitchCreateRequest
- Defined in:
- lib/plaid/models/deposit_switch_create_request.rb
Overview
DepositSwitchCreateRequest defines the request schema for ‘/deposit_switch/create`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#country_code ⇒ CountryCode1
ISO-3166-1 alpha-2 country code standard.
-
#options ⇒ DepositSwitchCreateRequestOptions
Options to configure the ‘/deposit_switch/create` request.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#target_access_token ⇒ String
Access token for the target Item, typically provided in the Import Item response.
-
#target_account_id ⇒ String
Plaid Account ID that specifies the target bank account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(target_access_token:, target_account_id:, client_id: SKIP, secret: SKIP, country_code: SKIP, options: SKIP, additional_properties: nil) ⇒ DepositSwitchCreateRequest
constructor
A new instance of DepositSwitchCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(target_access_token:, target_account_id:, client_id: SKIP, secret: SKIP, country_code: SKIP, options: SKIP, additional_properties: nil) ⇒ DepositSwitchCreateRequest
Returns a new instance of DepositSwitchCreateRequest.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 70 def initialize(target_access_token:, target_account_id:, client_id: SKIP, secret: SKIP, country_code: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @target_access_token = target_access_token @target_account_id = target_account_id @country_code = country_code unless country_code == SKIP @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 17 def client_id @client_id end |
#country_code ⇒ CountryCode1
ISO-3166-1 alpha-2 country code standard.
36 37 38 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 36 def country_code @country_code end |
#options ⇒ DepositSwitchCreateRequestOptions
Options to configure the ‘/deposit_switch/create` request. If provided, cannot be `null`.
41 42 43 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 41 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 22 def secret @secret end |
#target_access_token ⇒ String
Access token for the target Item, typically provided in the Import Item response.
27 28 29 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 27 def target_access_token @target_access_token end |
#target_account_id ⇒ String
Plaid Account ID that specifies the target bank account. This account will become the recipient for a user’s direct deposit.
32 33 34 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 32 def target_account_id @target_account_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. target_access_token = hash.key?('target_access_token') ? hash['target_access_token'] : nil target_account_id = hash.key?('target_account_id') ? hash['target_account_id'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP country_code = hash.key?('country_code') ? hash['country_code'] : SKIP = DepositSwitchCreateRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DepositSwitchCreateRequest.new(target_access_token: target_access_token, target_account_id: target_account_id, client_id: client_id, secret: secret, country_code: country_code, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 44 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['target_access_token'] = 'target_access_token' @_hash['target_account_id'] = 'target_account_id' @_hash['country_code'] = 'country_code' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
66 67 68 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 66 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
56 57 58 59 60 61 62 63 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 56 def self.optionals %w[ client_id secret country_code options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
125 126 127 128 129 130 131 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 125 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " target_access_token: #{@target_access_token.inspect}, target_account_id:"\ " #{@target_account_id.inspect}, country_code: #{@country_code.inspect}, options:"\ " #{@options.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
117 118 119 120 121 122 |
# File 'lib/plaid/models/deposit_switch_create_request.rb', line 117 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, target_access_token:"\ " #{@target_access_token}, target_account_id: #{@target_account_id}, country_code:"\ " #{@country_code}, options: #{@options}, additional_properties: #{@additional_properties}>" end |