Class: Plaid::DepositSwitchTokenCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::DepositSwitchTokenCreateRequest
- Defined in:
- lib/plaid/models/deposit_switch_token_create_request.rb
Overview
DepositSwitchTokenCreateRequest defines the request schema for ‘/deposit_switch/token/create`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#deposit_switch_id ⇒ String
The ID of the deposit switch.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(deposit_switch_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ DepositSwitchTokenCreateRequest
constructor
A new instance of DepositSwitchTokenCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(deposit_switch_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ DepositSwitchTokenCreateRequest
Returns a new instance of DepositSwitchTokenCreateRequest.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 50 def initialize(deposit_switch_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @deposit_switch_id = deposit_switch_id @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 17 def client_id @client_id end |
#deposit_switch_id ⇒ String
The ID of the deposit switch
26 27 28 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 26 def deposit_switch_id @deposit_switch_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. deposit_switch_id = hash.key?('deposit_switch_id') ? hash['deposit_switch_id'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DepositSwitchTokenCreateRequest.new(deposit_switch_id: deposit_switch_id, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['deposit_switch_id'] = 'deposit_switch_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 41 42 43 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 38 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " deposit_switch_id: #{@deposit_switch_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/plaid/models/deposit_switch_token_create_request.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, deposit_switch_id:"\ " #{@deposit_switch_id}, additional_properties: #{@additional_properties}>" end |