Class: Plaid::DocumentMetadata

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/document_metadata.rb

Overview

An object representing metadata from the end user’s uploaded document.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, status: SKIP, doc_id: SKIP, additional_properties: nil) ⇒ DocumentMetadata

Returns a new instance of DocumentMetadata.



48
49
50
51
52
53
54
55
56
57
# File 'lib/plaid/models/document_metadata.rb', line 48

def initialize(name: SKIP, status: SKIP, doc_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @status = status unless status == SKIP
  @doc_id = doc_id unless doc_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#doc_idString

An identifier of the document that is also present in the paystub response.

Returns:

  • (String)


23
24
25
# File 'lib/plaid/models/document_metadata.rb', line 23

def doc_id
  @doc_id
end

#nameString

The name of the document.

Returns:

  • (String)


14
15
16
# File 'lib/plaid/models/document_metadata.rb', line 14

def name
  @name
end

#statusString

The processing status of the document.

Returns:

  • (String)


18
19
20
# File 'lib/plaid/models/document_metadata.rb', line 18

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/plaid/models/document_metadata.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  doc_id = hash.key?('doc_id') ? hash['doc_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DocumentMetadata.new(name: name,
                       status: status,
                       doc_id: doc_id,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/plaid/models/document_metadata.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['status'] = 'status'
  @_hash['doc_id'] = 'doc_id'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/plaid/models/document_metadata.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/plaid/models/document_metadata.rb', line 35

def self.optionals
  %w[
    name
    status
    doc_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/plaid/models/document_metadata.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, status: #{@status.inspect}, doc_id:"\
  " #{@doc_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/plaid/models/document_metadata.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, status: #{@status}, doc_id: #{@doc_id},"\
  " additional_properties: #{@additional_properties}>"
end