Class: Plaid::Earnings
- Defined in:
- lib/plaid/models/earnings.rb
Overview
An object representing both a breakdown of earnings on a paystub and the total earnings.
Instance Attribute Summary collapse
-
#subtotals ⇒ Array[EarningsTotal]
TODO: Write general description for this method.
-
#totals ⇒ Array[EarningsTotal]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(subtotals: SKIP, totals: SKIP, additional_properties: nil) ⇒ Earnings
constructor
A new instance of Earnings.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(subtotals: SKIP, totals: SKIP, additional_properties: nil) ⇒ Earnings
Returns a new instance of Earnings.
42 43 44 45 46 47 48 49 |
# File 'lib/plaid/models/earnings.rb', line 42 def initialize(subtotals: SKIP, totals: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @subtotals = subtotals unless subtotals == SKIP @totals = totals unless totals == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#subtotals ⇒ Array[EarningsTotal]
TODO: Write general description for this method
15 16 17 |
# File 'lib/plaid/models/earnings.rb', line 15 def subtotals @subtotals end |
#totals ⇒ Array[EarningsTotal]
TODO: Write general description for this method
19 20 21 |
# File 'lib/plaid/models/earnings.rb', line 19 def totals @totals end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/plaid/models/earnings.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it subtotals = nil unless hash['subtotals'].nil? subtotals = [] hash['subtotals'].each do |structure| subtotals << (EarningsTotal.from_hash(structure) if structure) end end subtotals = SKIP unless hash.key?('subtotals') # Parameter is an array, so we need to iterate through it totals = nil unless hash['totals'].nil? totals = [] hash['totals'].each do |structure| totals << (EarningsTotal.from_hash(structure) if structure) end end totals = SKIP unless hash.key?('totals') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Earnings.new(subtotals: subtotals, totals: totals, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/plaid/models/earnings.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['subtotals'] = 'subtotals' @_hash['totals'] = 'totals' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/plaid/models/earnings.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/plaid/models/earnings.rb', line 30 def self.optionals %w[ subtotals totals ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/plaid/models/earnings.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} subtotals: #{@subtotals.inspect}, totals: #{@totals.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/plaid/models/earnings.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} subtotals: #{@subtotals}, totals: #{@totals}, additional_properties:"\ " #{@additional_properties}>" end |