Class: Plaid::HistoricalUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/historical_update_webhook.rb

Overview

Fired when an Item’s historical transaction pull is completed and Plaid has prepared as much historical transaction data as possible for the Item. Once this webhook has been fired, transaction data beyond the most recent 30 days can be fetched for the Item. If [Account Select v2](plaid.com/docs/link/customization/#account-select) is enabled, this webhook will also be fired if account selections for the Item are updated, with ‘num_transactions` set to the number of net new transactions pulled after the account selection update.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, new_transactions:, item_id:, error: SKIP, additional_properties: nil) ⇒ HistoricalUpdateWebhook

Returns a new instance of HistoricalUpdateWebhook.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/plaid/models/historical_update_webhook.rb', line 66

def initialize(webhook_type:, webhook_code:, new_transactions:, item_id:,
               error: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @error = error unless error == SKIP
  @new_transactions = new_transactions
  @item_id = item_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#errorError

We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`. In general, 200 HTTP codes correspond to success, 40X codes are for developer- or user-related failures, and 50X codes are for Plaid-related issues. Error fields will be `null` if no error has occurred.

Returns:



33
34
35
# File 'lib/plaid/models/historical_update_webhook.rb', line 33

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


41
42
43
# File 'lib/plaid/models/historical_update_webhook.rb', line 41

def item_id
  @item_id
end

#new_transactionsFloat

The number of new, unfetched transactions available

Returns:

  • (Float)


37
38
39
# File 'lib/plaid/models/historical_update_webhook.rb', line 37

def new_transactions
  @new_transactions
end

#webhook_codeString

‘HISTORICAL_UPDATE`

Returns:

  • (String)


25
26
27
# File 'lib/plaid/models/historical_update_webhook.rb', line 25

def webhook_code
  @webhook_code
end

#webhook_typeString

‘TRANSACTIONS`

Returns:

  • (String)


21
22
23
# File 'lib/plaid/models/historical_update_webhook.rb', line 21

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/plaid/models/historical_update_webhook.rb', line 80

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  new_transactions =
    hash.key?('new_transactions') ? hash['new_transactions'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  error = Error.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  HistoricalUpdateWebhook.new(webhook_type: webhook_type,
                              webhook_code: webhook_code,
                              new_transactions: new_transactions,
                              item_id: item_id,
                              error: error,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



44
45
46
47
48
49
50
51
52
# File 'lib/plaid/models/historical_update_webhook.rb', line 44

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['error'] = 'error'
  @_hash['new_transactions'] = 'new_transactions'
  @_hash['item_id'] = 'item_id'
  @_hash
end

.nullablesObject

An array for nullable fields



62
63
64
# File 'lib/plaid/models/historical_update_webhook.rb', line 62

def self.nullables
  []
end

.optionalsObject

An array for optional fields



55
56
57
58
59
# File 'lib/plaid/models/historical_update_webhook.rb', line 55

def self.optionals
  %w[
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



116
117
118
119
120
121
122
# File 'lib/plaid/models/historical_update_webhook.rb', line 116

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, error: #{@error.inspect}, new_transactions:"\
  " #{@new_transactions.inspect}, item_id: #{@item_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



108
109
110
111
112
113
# File 'lib/plaid/models/historical_update_webhook.rb', line 108

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\
  " #{@error}, new_transactions: #{@new_transactions}, item_id: #{@item_id},"\
  " additional_properties: #{@additional_properties}>"
end