Class: Plaid::IncomeVerificationPrecheckEmployer
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::IncomeVerificationPrecheckEmployer
- Defined in:
- lib/plaid/models/income_verification_precheck_employer.rb
Overview
IncomeVerificationPrecheckEmployer Model.
Instance Attribute Summary collapse
-
#name ⇒ String
The employer’s name.
-
#tax_id ⇒ String
The employer’s tax id.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, tax_id: SKIP, additional_properties: nil) ⇒ IncomeVerificationPrecheckEmployer
constructor
A new instance of IncomeVerificationPrecheckEmployer.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, tax_id: SKIP, additional_properties: nil) ⇒ IncomeVerificationPrecheckEmployer
Returns a new instance of IncomeVerificationPrecheckEmployer.
44 45 46 47 48 49 50 51 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 44 def initialize(name: SKIP, tax_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @tax_id = tax_id unless tax_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#name ⇒ String
The employer’s name
14 15 16 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 14 def name @name end |
#tax_id ⇒ String
The employer’s tax id
18 19 20 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 18 def tax_id @tax_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP tax_id = hash.key?('tax_id') ? hash['tax_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IncomeVerificationPrecheckEmployer.new(name: name, tax_id: tax_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['tax_id'] = 'tax_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 37 def self.nullables %w[ name tax_id ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 29 def self.optionals %w[ name tax_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, tax_id: #{@tax_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/plaid/models/income_verification_precheck_employer.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, tax_id: #{@tax_id}, additional_properties:"\ " #{@additional_properties}>" end |