Class: Plaid::InvestmentAccountSubtype

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/investment_account_subtype.rb

Overview

An investment account. Supported products for ‘investment` accounts are: Balance and Investments.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(m529a:, m401a:, m401k:, m403b:, m457b:, brokerage:, cash_isa:, education_savings_account:, fixed_annuity:, gic:, health_reimbursement_arrangement:, hsa:, ira:, isa:, keogh:, lif:, life_insurance:, lira:, lrif:, lrsp:, mutual_fund:, non_taxable_brokerage_account:, other:, other_annuity:, other_insurance:, pension:, prif:, profit_sharing_plan:, qshr:, rdsp:, resp:, retirement:, rlif:, roth:, roth_401k:, rrif:, rrsp:, sarsep:, sep_ira:, simple_ira:, sipp:, stock_plan:, tfsa:, trust:, ugma:, utma:, variable_annuity: SKIP, additional_properties: nil) ⇒ InvestmentAccountSubtype

Returns a new instance of InvestmentAccountSubtype.



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/plaid/models/investment_account_subtype.rb', line 275

def initialize(m529a:, m401a:, m401k:, m403b:, m457b:, brokerage:,
               cash_isa:, education_savings_account:, fixed_annuity:, gic:,
               health_reimbursement_arrangement:, hsa:, ira:, isa:, keogh:,
               lif:, life_insurance:, lira:, lrif:, lrsp:, mutual_fund:,
               non_taxable_brokerage_account:, other:, other_annuity:,
               other_insurance:, pension:, prif:, profit_sharing_plan:,
               qshr:, rdsp:, resp:, retirement:, rlif:, roth:, roth_401k:,
               rrif:, rrsp:, sarsep:, sep_ira:, simple_ira:, sipp:,
               stock_plan:, tfsa:, trust:, ugma:, utma:,
               variable_annuity: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @m529a = m529a
  @m401a = m401a
  @m401k = m401k
  @m403b = m403b
  @m457b = m457b
  @brokerage = brokerage
  @cash_isa = cash_isa
  @education_savings_account = 
  @fixed_annuity = fixed_annuity
  @gic = gic
  @health_reimbursement_arrangement = health_reimbursement_arrangement
  @hsa = hsa
  @ira = ira
  @isa = isa
  @keogh = keogh
  @lif = lif
  @life_insurance = life_insurance
  @lira = lira
  @lrif = lrif
  @lrsp = lrsp
  @mutual_fund = mutual_fund
  @non_taxable_brokerage_account = 
  @other = other
  @other_annuity = other_annuity
  @other_insurance = other_insurance
  @pension = pension
  @prif = prif
  @profit_sharing_plan = profit_sharing_plan
  @qshr = qshr
  @rdsp = rdsp
  @resp = resp
  @retirement = retirement
  @rlif = rlif
  @roth = roth
  @roth_401k = roth_401k
  @rrif = rrif
  @rrsp = rrsp
  @sarsep = sarsep
  @sep_ira = sep_ira
  @simple_ira = simple_ira
  @sipp = sipp
  @stock_plan = stock_plan
  @tfsa = tfsa
  @trust = trust
  @ugma = ugma
  @utma = utma
  @variable_annuity = variable_annuity unless variable_annuity == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#brokerageString

Standard brokerage account

Returns:

  • (String)


36
37
38
# File 'lib/plaid/models/investment_account_subtype.rb', line 36

def brokerage
  @brokerage
end

#cash_isaString

Individual Savings Account (ISA) that pays interest tax-free (UK)

Returns:

  • (String)


40
41
42
# File 'lib/plaid/models/investment_account_subtype.rb', line 40

def cash_isa
  @cash_isa
end

#education_savings_accountString

Tax-advantaged Coverdell Education Savings Account (ESA) (US)

Returns:

  • (String)


44
45
46
# File 'lib/plaid/models/investment_account_subtype.rb', line 44

def 
  @education_savings_account
end

#fixed_annuityString

Fixed annuity

Returns:

  • (String)


48
49
50
# File 'lib/plaid/models/investment_account_subtype.rb', line 48

def fixed_annuity
  @fixed_annuity
end

#gicString

Guaranteed Investment Certificate (Canada)

Returns:

  • (String)


52
53
54
# File 'lib/plaid/models/investment_account_subtype.rb', line 52

def gic
  @gic
end

#health_reimbursement_arrangementString

Tax-advantaged Health Reimbursement Arrangement (HRA) benefit plan (US)

Returns:

  • (String)


56
57
58
# File 'lib/plaid/models/investment_account_subtype.rb', line 56

def health_reimbursement_arrangement
  @health_reimbursement_arrangement
end

#hsaString

Non-cash tax-advantaged medical Health Savings Account (HSA) (US)

Returns:

  • (String)


60
61
62
# File 'lib/plaid/models/investment_account_subtype.rb', line 60

def hsa
  @hsa
end

#iraString

Traditional Invididual Retirement Account (IRA) (US)

Returns:

  • (String)


64
65
66
# File 'lib/plaid/models/investment_account_subtype.rb', line 64

def ira
  @ira
end

#isaString

Non-cash Individual Savings Account (ISA) (UK)

Returns:

  • (String)


68
69
70
# File 'lib/plaid/models/investment_account_subtype.rb', line 68

def isa
  @isa
end

#keoghString

Keogh self-employed retirement plan (US)

Returns:

  • (String)


72
73
74
# File 'lib/plaid/models/investment_account_subtype.rb', line 72

def keogh
  @keogh
end

#lifString

Life Income Fund (LIF) retirement account (Canada)

Returns:

  • (String)


76
77
78
# File 'lib/plaid/models/investment_account_subtype.rb', line 76

def lif
  @lif
end

#life_insuranceString

Life insurance account

Returns:

  • (String)


80
81
82
# File 'lib/plaid/models/investment_account_subtype.rb', line 80

def life_insurance
  @life_insurance
end

#liraString

Locked-in Retirement Account (LIRA) (Canada)

Returns:

  • (String)


84
85
86
# File 'lib/plaid/models/investment_account_subtype.rb', line 84

def lira
  @lira
end

#lrifString

Locked-in Retirement Income Fund (LRIF) (Canada)

Returns:

  • (String)


88
89
90
# File 'lib/plaid/models/investment_account_subtype.rb', line 88

def lrif
  @lrif
end

#lrspString

Locked-in Retirement Savings Plan (Canada)

Returns:

  • (String)


92
93
94
# File 'lib/plaid/models/investment_account_subtype.rb', line 92

def lrsp
  @lrsp
end

#m401aString

Employer-sponsored money-purchase 401(a) retirement plan (US)

Returns:

  • (String)


19
20
21
# File 'lib/plaid/models/investment_account_subtype.rb', line 19

def m401a
  @m401a
end

#m401kString

Standard 401(k) retirement account (US)

Returns:

  • (String)


23
24
25
# File 'lib/plaid/models/investment_account_subtype.rb', line 23

def m401k
  @m401k
end

#m403bString

403(b) retirement savings account for non-profits and schools (US)

Returns:

  • (String)


27
28
29
# File 'lib/plaid/models/investment_account_subtype.rb', line 27

def m403b
  @m403b
end

#m457bString

Tax-advantaged deferred-compensation 457(b) retirement plan for governments and non-profits (US)

Returns:

  • (String)


32
33
34
# File 'lib/plaid/models/investment_account_subtype.rb', line 32

def m457b
  @m457b
end

#m529aString

Tax-advantaged college savings and prepaid tuition 529 plans (US)

Returns:

  • (String)


15
16
17
# File 'lib/plaid/models/investment_account_subtype.rb', line 15

def m529a
  @m529a
end

#mutual_fundString

Mutual fund account

Returns:

  • (String)


96
97
98
# File 'lib/plaid/models/investment_account_subtype.rb', line 96

def mutual_fund
  @mutual_fund
end

#non_taxable_brokerage_accountString

A non-taxable brokerage account that is not covered by a more specific subtype

Returns:

  • (String)


101
102
103
# File 'lib/plaid/models/investment_account_subtype.rb', line 101

def 
  @non_taxable_brokerage_account
end

#otherString

An account whose type could not be determined

Returns:

  • (String)


105
106
107
# File 'lib/plaid/models/investment_account_subtype.rb', line 105

def other
  @other
end

#other_annuityString

An annuity account not covered by other subtypes

Returns:

  • (String)


109
110
111
# File 'lib/plaid/models/investment_account_subtype.rb', line 109

def other_annuity
  @other_annuity
end

#other_insuranceString

An insurance account not covered by other subtypes

Returns:

  • (String)


113
114
115
# File 'lib/plaid/models/investment_account_subtype.rb', line 113

def other_insurance
  @other_insurance
end

#pensionString

Standard pension account

Returns:

  • (String)


117
118
119
# File 'lib/plaid/models/investment_account_subtype.rb', line 117

def pension
  @pension
end

#prifString

Prescribed Registered Retirement Income Fund (Canada)

Returns:

  • (String)


121
122
123
# File 'lib/plaid/models/investment_account_subtype.rb', line 121

def prif
  @prif
end

#profit_sharing_planString

Plan that gives employees share of company profits

Returns:

  • (String)


125
126
127
# File 'lib/plaid/models/investment_account_subtype.rb', line 125

def profit_sharing_plan
  @profit_sharing_plan
end

#qshrString

Qualifying share account

Returns:

  • (String)


129
130
131
# File 'lib/plaid/models/investment_account_subtype.rb', line 129

def qshr
  @qshr
end

#rdspString

Registered Disability Savings Plan (RSDP) (Canada)

Returns:

  • (String)


133
134
135
# File 'lib/plaid/models/investment_account_subtype.rb', line 133

def rdsp
  @rdsp
end

#respString

Registered Education Savings Plan (Canada)

Returns:

  • (String)


137
138
139
# File 'lib/plaid/models/investment_account_subtype.rb', line 137

def resp
  @resp
end

#retirementString

Retirement account not covered by other subtypes

Returns:

  • (String)


141
142
143
# File 'lib/plaid/models/investment_account_subtype.rb', line 141

def retirement
  @retirement
end

#rlifString

Restricted Life Income Fund (RLIF) (Canada)

Returns:

  • (String)


145
146
147
# File 'lib/plaid/models/investment_account_subtype.rb', line 145

def rlif
  @rlif
end

#rothString

Roth IRA (US)

Returns:

  • (String)


149
150
151
# File 'lib/plaid/models/investment_account_subtype.rb', line 149

def roth
  @roth
end

#roth_401kString

Employer-sponsored Roth 401(k) plan (US)

Returns:

  • (String)


153
154
155
# File 'lib/plaid/models/investment_account_subtype.rb', line 153

def roth_401k
  @roth_401k
end

#rrifString

Registered Retirement Income Fund (RRIF) (Canada)

Returns:

  • (String)


157
158
159
# File 'lib/plaid/models/investment_account_subtype.rb', line 157

def rrif
  @rrif
end

#rrspString

Registered Retirement Savings Plan (Canadian, similar to US 401(k))

Returns:

  • (String)


161
162
163
# File 'lib/plaid/models/investment_account_subtype.rb', line 161

def rrsp
  @rrsp
end

#sarsepString

Salary Reduction Simplified Employee Pension Plan (SARSEP), discontinued retirement plan (US)

Returns:

  • (String)


166
167
168
# File 'lib/plaid/models/investment_account_subtype.rb', line 166

def sarsep
  @sarsep
end

#sep_iraString

Simplified Employee Pension IRA (SEP IRA), retirement plan for small businesses and self-employed (US)

Returns:

  • (String)


171
172
173
# File 'lib/plaid/models/investment_account_subtype.rb', line 171

def sep_ira
  @sep_ira
end

#simple_iraString

Savings Incentive Match Plan for Employees IRA, retirement plan for small businesses (US)

Returns:

  • (String)


176
177
178
# File 'lib/plaid/models/investment_account_subtype.rb', line 176

def simple_ira
  @simple_ira
end

#sippString

Self-Invested Personal Pension (SIPP) (UK)

Returns:

  • (String)


180
181
182
# File 'lib/plaid/models/investment_account_subtype.rb', line 180

def sipp
  @sipp
end

#stock_planString

Standard stock plan account

Returns:

  • (String)


184
185
186
# File 'lib/plaid/models/investment_account_subtype.rb', line 184

def stock_plan
  @stock_plan
end

#tfsaString

Tax-Free Savings Account (TFSA), a retirement plan similar to a Roth IRA (Canada)

Returns:

  • (String)


189
190
191
# File 'lib/plaid/models/investment_account_subtype.rb', line 189

def tfsa
  @tfsa
end

#trustString

Account representing funds or assets held by a trustee for the benefit of a beneficiary. Includes both revocable and irrevocable trusts.

Returns:

  • (String)


194
195
196
# File 'lib/plaid/models/investment_account_subtype.rb', line 194

def trust
  @trust
end

#ugmaString

‘Uniform Gift to Minors Act’ (brokerage account for minors, US)

Returns:

  • (String)


198
199
200
# File 'lib/plaid/models/investment_account_subtype.rb', line 198

def ugma
  @ugma
end

#utmaString

‘Uniform Transfers to Minors Act’ (brokerage account for minors, US)

Returns:

  • (String)


202
203
204
# File 'lib/plaid/models/investment_account_subtype.rb', line 202

def utma
  @utma
end

#variable_annuityString

Tax-deferred capital accumulation annuity contract

Returns:

  • (String)


206
207
208
# File 'lib/plaid/models/investment_account_subtype.rb', line 206

def variable_annuity
  @variable_annuity
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/plaid/models/investment_account_subtype.rb', line 339

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  m529a = hash.key?('529a') ? hash['529a'] : nil
  m401a = hash.key?('401a') ? hash['401a'] : nil
  m401k = hash.key?('401k') ? hash['401k'] : nil
  m403b = hash.key?('403b') ? hash['403b'] : nil
  m457b = hash.key?('457b') ? hash['457b'] : nil
  brokerage = hash.key?('brokerage') ? hash['brokerage'] : nil
  cash_isa = hash.key?('cash isa') ? hash['cash isa'] : nil
   =
    hash.key?('education savings account') ? hash['education savings account'] : nil
  fixed_annuity = hash.key?('fixed annuity') ? hash['fixed annuity'] : nil
  gic = hash.key?('gic') ? hash['gic'] : nil
  health_reimbursement_arrangement =
    hash.key?('health reimbursement arrangement') ? hash['health reimbursement arrangement'] : nil
  hsa = hash.key?('hsa') ? hash['hsa'] : nil
  ira = hash.key?('ira') ? hash['ira'] : nil
  isa = hash.key?('isa') ? hash['isa'] : nil
  keogh = hash.key?('keogh') ? hash['keogh'] : nil
  lif = hash.key?('lif') ? hash['lif'] : nil
  life_insurance =
    hash.key?('life insurance') ? hash['life insurance'] : nil
  lira = hash.key?('lira') ? hash['lira'] : nil
  lrif = hash.key?('lrif') ? hash['lrif'] : nil
  lrsp = hash.key?('lrsp') ? hash['lrsp'] : nil
  mutual_fund = hash.key?('mutual fund') ? hash['mutual fund'] : nil
   =
    hash.key?('non-taxable brokerage account') ? hash['non-taxable brokerage account'] : nil
  other = hash.key?('other') ? hash['other'] : nil
  other_annuity = hash.key?('other annuity') ? hash['other annuity'] : nil
  other_insurance =
    hash.key?('other insurance') ? hash['other insurance'] : nil
  pension = hash.key?('pension') ? hash['pension'] : nil
  prif = hash.key?('prif') ? hash['prif'] : nil
  profit_sharing_plan =
    hash.key?('profit sharing plan') ? hash['profit sharing plan'] : nil
  qshr = hash.key?('qshr') ? hash['qshr'] : nil
  rdsp = hash.key?('rdsp') ? hash['rdsp'] : nil
  resp = hash.key?('resp') ? hash['resp'] : nil
  retirement = hash.key?('retirement') ? hash['retirement'] : nil
  rlif = hash.key?('rlif') ? hash['rlif'] : nil
  roth = hash.key?('roth') ? hash['roth'] : nil
  roth_401k = hash.key?('roth 401k') ? hash['roth 401k'] : nil
  rrif = hash.key?('rrif') ? hash['rrif'] : nil
  rrsp = hash.key?('rrsp') ? hash['rrsp'] : nil
  sarsep = hash.key?('sarsep') ? hash['sarsep'] : nil
  sep_ira = hash.key?('sep ira') ? hash['sep ira'] : nil
  simple_ira = hash.key?('simple ira') ? hash['simple ira'] : nil
  sipp = hash.key?('sipp') ? hash['sipp'] : nil
  stock_plan = hash.key?('stock plan') ? hash['stock plan'] : nil
  tfsa = hash.key?('tfsa') ? hash['tfsa'] : nil
  trust = hash.key?('trust') ? hash['trust'] : nil
  ugma = hash.key?('ugma') ? hash['ugma'] : nil
  utma = hash.key?('utma') ? hash['utma'] : nil
  variable_annuity =
    hash.key?('variable annuity') ? hash['variable annuity'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InvestmentAccountSubtype.new(m529a: m529a,
                               m401a: m401a,
                               m401k: m401k,
                               m403b: m403b,
                               m457b: m457b,
                               brokerage: brokerage,
                               cash_isa: cash_isa,
                               education_savings_account: ,
                               fixed_annuity: fixed_annuity,
                               gic: gic,
                               health_reimbursement_arrangement: health_reimbursement_arrangement,
                               hsa: hsa,
                               ira: ira,
                               isa: isa,
                               keogh: keogh,
                               lif: lif,
                               life_insurance: life_insurance,
                               lira: lira,
                               lrif: lrif,
                               lrsp: lrsp,
                               mutual_fund: mutual_fund,
                               non_taxable_brokerage_account: ,
                               other: other,
                               other_annuity: other_annuity,
                               other_insurance: other_insurance,
                               pension: pension,
                               prif: prif,
                               profit_sharing_plan: profit_sharing_plan,
                               qshr: qshr,
                               rdsp: rdsp,
                               resp: resp,
                               retirement: retirement,
                               rlif: rlif,
                               roth: roth,
                               roth_401k: roth_401k,
                               rrif: rrif,
                               rrsp: rrsp,
                               sarsep: sarsep,
                               sep_ira: sep_ira,
                               simple_ira: simple_ira,
                               sipp: sipp,
                               stock_plan: stock_plan,
                               tfsa: tfsa,
                               trust: trust,
                               ugma: ugma,
                               utma: utma,
                               variable_annuity: variable_annuity,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/plaid/models/investment_account_subtype.rb', line 209

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['m529a'] = '529a'
  @_hash['m401a'] = '401a'
  @_hash['m401k'] = '401k'
  @_hash['m403b'] = '403b'
  @_hash['m457b'] = '457b'
  @_hash['brokerage'] = 'brokerage'
  @_hash['cash_isa'] = 'cash isa'
  @_hash['education_savings_account'] = 'education savings account'
  @_hash['fixed_annuity'] = 'fixed annuity'
  @_hash['gic'] = 'gic'
  @_hash['health_reimbursement_arrangement'] =
    'health reimbursement arrangement'
  @_hash['hsa'] = 'hsa'
  @_hash['ira'] = 'ira'
  @_hash['isa'] = 'isa'
  @_hash['keogh'] = 'keogh'
  @_hash['lif'] = 'lif'
  @_hash['life_insurance'] = 'life insurance'
  @_hash['lira'] = 'lira'
  @_hash['lrif'] = 'lrif'
  @_hash['lrsp'] = 'lrsp'
  @_hash['mutual_fund'] = 'mutual fund'
  @_hash['non_taxable_brokerage_account'] =
    'non-taxable brokerage account'
  @_hash['other'] = 'other'
  @_hash['other_annuity'] = 'other annuity'
  @_hash['other_insurance'] = 'other insurance'
  @_hash['pension'] = 'pension'
  @_hash['prif'] = 'prif'
  @_hash['profit_sharing_plan'] = 'profit sharing plan'
  @_hash['qshr'] = 'qshr'
  @_hash['rdsp'] = 'rdsp'
  @_hash['resp'] = 'resp'
  @_hash['retirement'] = 'retirement'
  @_hash['rlif'] = 'rlif'
  @_hash['roth'] = 'roth'
  @_hash['roth_401k'] = 'roth 401k'
  @_hash['rrif'] = 'rrif'
  @_hash['rrsp'] = 'rrsp'
  @_hash['sarsep'] = 'sarsep'
  @_hash['sep_ira'] = 'sep ira'
  @_hash['simple_ira'] = 'simple ira'
  @_hash['sipp'] = 'sipp'
  @_hash['stock_plan'] = 'stock plan'
  @_hash['tfsa'] = 'tfsa'
  @_hash['trust'] = 'trust'
  @_hash['ugma'] = 'ugma'
  @_hash['utma'] = 'utma'
  @_hash['variable_annuity'] = 'variable annuity'
  @_hash
end

.nullablesObject

An array for nullable fields



271
272
273
# File 'lib/plaid/models/investment_account_subtype.rb', line 271

def self.nullables
  []
end

.optionalsObject

An array for optional fields



264
265
266
267
268
# File 'lib/plaid/models/investment_account_subtype.rb', line 264

def self.optionals
  %w[
    variable_annuity
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/plaid/models/investment_account_subtype.rb', line 477

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} m529a: #{@m529a.inspect}, m401a: #{@m401a.inspect}, m401k:"\
  " #{@m401k.inspect}, m403b: #{@m403b.inspect}, m457b: #{@m457b.inspect}, brokerage:"\
  " #{@brokerage.inspect}, cash_isa: #{@cash_isa.inspect}, education_savings_account:"\
  " #{@education_savings_account.inspect}, fixed_annuity: #{@fixed_annuity.inspect}, gic:"\
  " #{@gic.inspect}, health_reimbursement_arrangement:"\
  " #{@health_reimbursement_arrangement.inspect}, hsa: #{@hsa.inspect}, ira: #{@ira.inspect},"\
  " isa: #{@isa.inspect}, keogh: #{@keogh.inspect}, lif: #{@lif.inspect}, life_insurance:"\
  " #{@life_insurance.inspect}, lira: #{@lira.inspect}, lrif: #{@lrif.inspect}, lrsp:"\
  " #{@lrsp.inspect}, mutual_fund: #{@mutual_fund.inspect}, non_taxable_brokerage_account:"\
  " #{@non_taxable_brokerage_account.inspect}, other: #{@other.inspect}, other_annuity:"\
  " #{@other_annuity.inspect}, other_insurance: #{@other_insurance.inspect}, pension:"\
  " #{@pension.inspect}, prif: #{@prif.inspect}, profit_sharing_plan:"\
  " #{@profit_sharing_plan.inspect}, qshr: #{@qshr.inspect}, rdsp: #{@rdsp.inspect}, resp:"\
  " #{@resp.inspect}, retirement: #{@retirement.inspect}, rlif: #{@rlif.inspect}, roth:"\
  " #{@roth.inspect}, roth_401k: #{@roth_401k.inspect}, rrif: #{@rrif.inspect}, rrsp:"\
  " #{@rrsp.inspect}, sarsep: #{@sarsep.inspect}, sep_ira: #{@sep_ira.inspect}, simple_ira:"\
  " #{@simple_ira.inspect}, sipp: #{@sipp.inspect}, stock_plan: #{@stock_plan.inspect}, tfsa:"\
  " #{@tfsa.inspect}, trust: #{@trust.inspect}, ugma: #{@ugma.inspect}, utma:"\
  " #{@utma.inspect}, variable_annuity: #{@variable_annuity.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/plaid/models/investment_account_subtype.rb', line 457

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} m529a: #{@m529a}, m401a: #{@m401a}, m401k: #{@m401k}, m403b: #{@m403b},"\
  " m457b: #{@m457b}, brokerage: #{@brokerage}, cash_isa: #{@cash_isa},"\
  " education_savings_account: #{@education_savings_account}, fixed_annuity:"\
  " #{@fixed_annuity}, gic: #{@gic}, health_reimbursement_arrangement:"\
  " #{@health_reimbursement_arrangement}, hsa: #{@hsa}, ira: #{@ira}, isa: #{@isa}, keogh:"\
  " #{@keogh}, lif: #{@lif}, life_insurance: #{@life_insurance}, lira: #{@lira}, lrif:"\
  " #{@lrif}, lrsp: #{@lrsp}, mutual_fund: #{@mutual_fund}, non_taxable_brokerage_account:"\
  " #{@non_taxable_brokerage_account}, other: #{@other}, other_annuity: #{@other_annuity},"\
  " other_insurance: #{@other_insurance}, pension: #{@pension}, prif: #{@prif},"\
  " profit_sharing_plan: #{@profit_sharing_plan}, qshr: #{@qshr}, rdsp: #{@rdsp}, resp:"\
  " #{@resp}, retirement: #{@retirement}, rlif: #{@rlif}, roth: #{@roth}, roth_401k:"\
  " #{@roth_401k}, rrif: #{@rrif}, rrsp: #{@rrsp}, sarsep: #{@sarsep}, sep_ira: #{@sep_ira},"\
  " simple_ira: #{@simple_ira}, sipp: #{@sipp}, stock_plan: #{@stock_plan}, tfsa: #{@tfsa},"\
  " trust: #{@trust}, ugma: #{@ugma}, utma: #{@utma}, variable_annuity: #{@variable_annuity},"\
  " additional_properties: #{@additional_properties}>"
end