Class: Plaid::ItemImportRequest
- Defined in:
- lib/plaid/models/item_import_request.rb
Overview
ItemImportRequest defines the request schema for ‘/item/import`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#options ⇒ ItemImportRequestOptions
An optional object to configure ‘/item/import` request.
-
#products ⇒ Array[Products]
Array of product strings.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#user_auth ⇒ ItemImportRequestUserAuth
Object of user ID and auth token pair, permitting Plaid to aggregate a user’s accounts.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(products:, user_auth:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ ItemImportRequest
constructor
A new instance of ItemImportRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(products:, user_auth:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ ItemImportRequest
Returns a new instance of ItemImportRequest.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/plaid/models/item_import_request.rb', line 61 def initialize(products:, user_auth:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @products = products @user_auth = user_auth @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/plaid/models/item_import_request.rb', line 16 def client_id @client_id end |
#options ⇒ ItemImportRequestOptions
An optional object to configure ‘/item/import` request.
34 35 36 |
# File 'lib/plaid/models/item_import_request.rb', line 34 def @options end |
#products ⇒ Array[Products]
Array of product strings
25 26 27 |
# File 'lib/plaid/models/item_import_request.rb', line 25 def products @products end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/plaid/models/item_import_request.rb', line 21 def secret @secret end |
#user_auth ⇒ ItemImportRequestUserAuth
Object of user ID and auth token pair, permitting Plaid to aggregate a user’s accounts
30 31 32 |
# File 'lib/plaid/models/item_import_request.rb', line 30 def user_auth @user_auth end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/plaid/models/item_import_request.rb', line 75 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. products = hash.key?('products') ? hash['products'] : nil user_auth = ItemImportRequestUserAuth.from_hash(hash['user_auth']) if hash['user_auth'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = ItemImportRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemImportRequest.new(products: products, user_auth: user_auth, client_id: client_id, secret: secret, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 |
# File 'lib/plaid/models/item_import_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['products'] = 'products' @_hash['user_auth'] = 'user_auth' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/plaid/models/item_import_request.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 |
# File 'lib/plaid/models/item_import_request.rb', line 48 def self.optionals %w[ client_id secret options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 |
# File 'lib/plaid/models/item_import_request.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, products:"\ " #{@products.inspect}, user_auth: #{@user_auth.inspect}, options: #{@options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
102 103 104 105 106 107 |
# File 'lib/plaid/models/item_import_request.rb', line 102 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, products: #{@products},"\ " user_auth: #{@user_auth}, options: #{@options}, additional_properties:"\ " #{@additional_properties}>" end |