Class: Plaid::ItemStatusNullable

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/item_status_nullable.rb

Overview

ItemStatusNullable Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(investments: SKIP, transactions: SKIP, last_webhook: SKIP, additional_properties: nil) ⇒ ItemStatusNullable

Returns a new instance of ItemStatusNullable.



49
50
51
52
53
54
55
56
57
58
# File 'lib/plaid/models/item_status_nullable.rb', line 49

def initialize(investments: SKIP, transactions: SKIP, last_webhook: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @investments = investments unless investments == SKIP
  @transactions = transactions unless transactions == SKIP
  @last_webhook = last_webhook unless last_webhook == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#investmentsItemStatusInvestments

Information about the last successful and failed investments update for the Item.



15
16
17
# File 'lib/plaid/models/item_status_nullable.rb', line 15

def investments
  @investments
end

#last_webhookItemStatusLastWebhook

Information about the last webhook fired for the Item.



24
25
26
# File 'lib/plaid/models/item_status_nullable.rb', line 24

def last_webhook
  @last_webhook
end

#transactionsItemStatusTransactions

Information about the last successful and failed transactions update for the Item.



20
21
22
# File 'lib/plaid/models/item_status_nullable.rb', line 20

def transactions
  @transactions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/plaid/models/item_status_nullable.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  investments = ItemStatusInvestments.from_hash(hash['investments']) if hash['investments']
  transactions = ItemStatusTransactions.from_hash(hash['transactions']) if
    hash['transactions']
  last_webhook = ItemStatusLastWebhook.from_hash(hash['last_webhook']) if hash['last_webhook']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemStatusNullable.new(investments: investments,
                         transactions: transactions,
                         last_webhook: last_webhook,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/plaid/models/item_status_nullable.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['investments'] = 'investments'
  @_hash['transactions'] = 'transactions'
  @_hash['last_webhook'] = 'last_webhook'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/plaid/models/item_status_nullable.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/plaid/models/item_status_nullable.rb', line 36

def self.optionals
  %w[
    investments
    transactions
    last_webhook
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/plaid/models/item_status_nullable.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} investments: #{@investments.inspect}, transactions:"\
  " #{@transactions.inspect}, last_webhook: #{@last_webhook.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/plaid/models/item_status_nullable.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} investments: #{@investments}, transactions: #{@transactions}, last_webhook:"\
  " #{@last_webhook}, additional_properties: #{@additional_properties}>"
end