Class: Plaid::LinkTokenCreateRequestAuth

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/link_token_create_request_auth.rb

Overview

Specifies options for initializing Link for use with the Auth product. This field is currently only required if using the Flexible Auth product (currently in closed beta).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(flow_type:, additional_properties: nil) ⇒ LinkTokenCreateRequestAuth

Returns a new instance of LinkTokenCreateRequestAuth.



36
37
38
39
40
41
42
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 36

def initialize(flow_type:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @flow_type = flow_type
  @additional_properties = additional_properties
end

Instance Attribute Details

#flow_typeString

The optional Auth flow to use. Currently only used to enable Flexible Auth.

Returns:

  • (String)


17
18
19
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 17

def flow_type
  @flow_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  flow_type = hash.key?('flow_type') ? hash['flow_type'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestAuth.new(flow_type: flow_type,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['flow_type'] = 'flow_type'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 27

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
75
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} flow_type: #{@flow_type.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
68
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} flow_type: #{@flow_type}, additional_properties:"\
  " #{@additional_properties}>"
end