Class: Plaid::LinkTokenCreateRequestUpdate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/link_token_create_request_update.rb

Overview

Specifies options for initializing Link for [update mode](plaid.com/docs/link/update-mode).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_selection_enabled: false, additional_properties: nil) ⇒ LinkTokenCreateRequestUpdate

Returns a new instance of LinkTokenCreateRequestUpdate.



38
39
40
41
42
43
44
45
46
47
# File 'lib/plaid/models/link_token_create_request_update.rb', line 38

def initialize(account_selection_enabled: false, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless  == SKIP
    @account_selection_enabled =
      
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_selection_enabledTrueClass | FalseClass

If ‘true`, enables [update mode with Account Select](plaid.com/docs/link/update-mode/#using-update-mode-to-requ est-new-accounts).

Returns:

  • (TrueClass | FalseClass)


17
18
19
# File 'lib/plaid/models/link_token_create_request_update.rb', line 17

def 
  @account_selection_enabled
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/plaid/models/link_token_create_request_update.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash['account_selection_enabled'] ||= false

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestUpdate.new(account_selection_enabled: ,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/plaid/models/link_token_create_request_update.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_selection_enabled'] = 'account_selection_enabled'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/plaid/models/link_token_create_request_update.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
30
31
# File 'lib/plaid/models/link_token_create_request_update.rb', line 27

def self.optionals
  %w[
    account_selection_enabled
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/plaid/models/link_token_create_request_update.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_selection_enabled: #{@account_selection_enabled.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
73
# File 'lib/plaid/models/link_token_create_request_update.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_selection_enabled: #{@account_selection_enabled},"\
  " additional_properties: #{@additional_properties}>"
end