Class: Plaid::Meta
- Defined in:
- lib/plaid/models/meta.rb
Overview
Allows specifying the metadata of the test account
Instance Attribute Summary collapse
-
#limit ⇒ Float
The account’s limit.
-
#name ⇒ String
The account’s name.
-
#official_name ⇒ String
The account’s official name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, official_name:, limit:, additional_properties: nil) ⇒ Meta
constructor
A new instance of Meta.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, official_name:, limit:, additional_properties: nil) ⇒ Meta
Returns a new instance of Meta.
43 44 45 46 47 48 49 50 51 |
# File 'lib/plaid/models/meta.rb', line 43 def initialize(name:, official_name:, limit:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @official_name = official_name @limit = limit @additional_properties = additional_properties end |
Instance Attribute Details
#limit ⇒ Float
The account’s limit
22 23 24 |
# File 'lib/plaid/models/meta.rb', line 22 def limit @limit end |
#name ⇒ String
The account’s name
14 15 16 |
# File 'lib/plaid/models/meta.rb', line 14 def name @name end |
#official_name ⇒ String
The account’s official name
18 19 20 |
# File 'lib/plaid/models/meta.rb', line 18 def official_name @official_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/plaid/models/meta.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil official_name = hash.key?('official_name') ? hash['official_name'] : nil limit = hash.key?('limit') ? hash['limit'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Meta.new(name: name, official_name: official_name, limit: limit, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/plaid/models/meta.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['official_name'] = 'official_name' @_hash['limit'] = 'limit' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/plaid/models/meta.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/plaid/models/meta.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/plaid/models/meta.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, official_name: #{@official_name.inspect}, limit:"\ " #{@limit.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/plaid/models/meta.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, official_name: #{@official_name}, limit: #{@limit},"\ " additional_properties: #{@additional_properties}>" end |