Class: Plaid::NewAccountsAvailableWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/new_accounts_available_webhook.rb

Overview

Fired when Plaid detects a new account for Items created or updated with [Account Select v2](plaid.com/docs/link/customization/#account-select). Upon receiving this webhook, you can prompt your users to share new accounts with you through [Account Select v2 update mode](plaid.com/docs/link/update-mode/#using-update-mode-to-request- new-accounts).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type: SKIP, webhook_code: SKIP, item_id: SKIP, error: SKIP, additional_properties: nil) ⇒ NewAccountsAvailableWebhook

Returns a new instance of NewAccountsAvailableWebhook.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 63

def initialize(webhook_type: SKIP, webhook_code: SKIP, item_id: SKIP,
               error: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type unless webhook_type == SKIP
  @webhook_code = webhook_code unless webhook_code == SKIP
  @item_id = item_id unless item_id == SKIP
  @error = error unless error == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#errorError

We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`. In general, 200 HTTP codes correspond to success, 40X codes are for developer- or user-related failures, and 50X codes are for Plaid-related issues. Error fields will be `null` if no error has occurred.

Returns:



36
37
38
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 36

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


28
29
30
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 28

def item_id
  @item_id
end

#webhook_codeString

‘NEW_ACCOUNTS_AVAILABLE`

Returns:

  • (String)


24
25
26
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 24

def webhook_code
  @webhook_code
end

#webhook_typeString

‘ITEM`

Returns:

  • (String)


20
21
22
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 20

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : SKIP
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : SKIP
  item_id = hash.key?('item_id') ? hash['item_id'] : SKIP
  error = Error.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  NewAccountsAvailableWebhook.new(webhook_type: webhook_type,
                                  webhook_code: webhook_code,
                                  item_id: item_id,
                                  error: error,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



39
40
41
42
43
44
45
46
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 39

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['error'] = 'error'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 49

def self.optionals
  %w[
    webhook_type
    webhook_code
    item_id
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
113
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, error: #{@error.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
# File 'lib/plaid/models/new_accounts_available_webhook.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, error: #{@error}, additional_properties: #{@additional_properties}>"
end