Class: Plaid::NumbersBacsNullable
- Defined in:
- lib/plaid/models/numbers_bacs_nullable.rb
Overview
NumbersBacsNullable Model.
Instance Attribute Summary collapse
-
#account ⇒ String
The BACS account number for the account.
-
#account_id ⇒ String
The Plaid account ID associated with the account numbers.
-
#sort_code ⇒ String
The BACS sort code for the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_id:, account:, sort_code:, additional_properties: nil) ⇒ NumbersBacsNullable
constructor
A new instance of NumbersBacsNullable.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_id:, account:, sort_code:, additional_properties: nil) ⇒ NumbersBacsNullable
Returns a new instance of NumbersBacsNullable.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 43 def initialize(account_id:, account:, sort_code:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_id = account_id @account = account @sort_code = sort_code @additional_properties = additional_properties end |
Instance Attribute Details
#account ⇒ String
The BACS account number for the account
18 19 20 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 18 def account @account end |
#account_id ⇒ String
The Plaid account ID associated with the account numbers
14 15 16 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 14 def account_id @account_id end |
#sort_code ⇒ String
The BACS sort code for the account
22 23 24 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 22 def sort_code @sort_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_id = hash.key?('account_id') ? hash['account_id'] : nil account = hash.key?('account') ? hash['account'] : nil sort_code = hash.key?('sort_code') ? hash['sort_code'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. NumbersBacsNullable.new(account_id: account_id, account: account, sort_code: sort_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['account_id'] = 'account_id' @_hash['account'] = 'account' @_hash['sort_code'] = 'sort_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id.inspect}, account: #{@account.inspect},"\ " sort_code: #{@sort_code.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/plaid/models/numbers_bacs_nullable.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id}, account: #{@account}, sort_code: #{@sort_code},"\ " additional_properties: #{@additional_properties}>" end |