Class: Plaid::PaymentInitiationPaymentListRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/payment_initiation_payment_list_request.rb

Overview

PaymentInitiationPaymentListRequest defines the request schema for ‘/payment_initiation/payment/list`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_id: SKIP, secret: SKIP, count: 10, cursor: SKIP, additional_properties: nil) ⇒ PaymentInitiationPaymentListRequest

Returns a new instance of PaymentInitiationPaymentListRequest.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 64

def initialize(client_id: SKIP, secret: SKIP, count: 10, cursor: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @count = count unless count == SKIP
  @cursor = cursor unless cursor == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


18
19
20
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 18

def client_id
  @client_id
end

#countInteger

The maximum number of payments to return. If ‘count` is not specified, a maximum of 10 payments will be returned, beginning with the most recent payment before the cursor (if specified).

Returns:

  • (Integer)


29
30
31
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 29

def count
  @count
end

#cursorDateTime

A string in RFC 3339 format (i.e. “2019-12-06T22:35:49Z”). Only payments created before the cursor will be returned.

Returns:

  • (DateTime)


34
35
36
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 34

def cursor
  @cursor
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


23
24
25
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 23

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 77

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  count = hash['count'] ||= 10
  cursor = if hash.key?('cursor')
             (DateTimeHelper.from_rfc3339(hash['cursor']) if hash['cursor'])
           else
             SKIP
           end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInitiationPaymentListRequest.new(client_id: client_id,
                                          secret: secret,
                                          count: count,
                                          cursor: cursor,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['count'] = 'count'
  @_hash['cursor'] = 'cursor'
  @_hash
end

.nullablesObject

An array for nullable fields



57
58
59
60
61
62
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 57

def self.nullables
  %w[
    count
    cursor
  ]
end

.optionalsObject

An array for optional fields



47
48
49
50
51
52
53
54
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 47

def self.optionals
  %w[
    client_id
    secret
    count
    cursor
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



117
118
119
120
121
122
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 117

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, count:"\
  " #{@count.inspect}, cursor: #{@cursor.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_cursorObject



105
106
107
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 105

def to_custom_cursor
  DateTimeHelper.to_rfc3339(cursor)
end

#to_sObject

Provides a human-readable string representation of the object.



110
111
112
113
114
# File 'lib/plaid/models/payment_initiation_payment_list_request.rb', line 110

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, count: #{@count}, cursor:"\
  " #{@cursor}, additional_properties: #{@additional_properties}>"
end