Class: Plaid::PaymentInitiationPaymentReverseResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/payment_initiation_payment_reverse_response.rb

Overview

PaymentInitiationPaymentReverseResponse defines the response schema for ‘/payment_initation/payment/reverse`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(refund_id:, status:, request_id:, additional_properties: nil) ⇒ PaymentInitiationPaymentReverseResponse

Returns a new instance of PaymentInitiationPaymentReverseResponse.



52
53
54
55
56
57
58
59
60
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 52

def initialize(refund_id:, status:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @refund_id = refund_id
  @status = status
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#refund_idString

A unique ID identifying the refund

Returns:

  • (String)


15
16
17
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 15

def refund_id
  @refund_id
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


31
32
33
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 31

def request_id
  @request_id
end

#statusStatus2

The status of the refund. ‘PROCESSING`: The refund is currently being processed. The refund will automatically exit this state when processing is complete. `INITIATED`: The refund has been successfully initiated. `EXECUTED`: Indicates that the refund has been successfully executed. `FAILED`: The refund has failed to be executed. This error is retryable once the root cause is resolved.

Returns:



25
26
27
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 25

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  refund_id = hash.key?('refund_id') ? hash['refund_id'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInitiationPaymentReverseResponse.new(refund_id: refund_id,
                                              status: status,
                                              request_id: request_id,
                                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
40
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['refund_id'] = 'refund_id'
  @_hash['status'] = 'status'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



48
49
50
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 48

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 43

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} refund_id: #{@refund_id.inspect}, status: #{@status.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/plaid/models/payment_initiation_payment_reverse_response.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} refund_id: #{@refund_id}, status: #{@status}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end