Class: Plaid::PaystubOverride
- Defined in:
- lib/plaid/models/paystub_override.rb
Overview
An object representing data from a paystub.
Instance Attribute Summary collapse
-
#employee ⇒ Employee2
The employee on the paystub.
-
#employer ⇒ Employer3
The employer on the paystub.
-
#income_breakdown ⇒ Array[IncomeBreakdown]
The employee on the paystub.
-
#pay_period_details ⇒ PayPeriodDetails
Details about the pay period.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(employer: SKIP, employee: SKIP, income_breakdown: SKIP, pay_period_details: SKIP, additional_properties: nil) ⇒ PaystubOverride
constructor
A new instance of PaystubOverride.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(employer: SKIP, employee: SKIP, income_breakdown: SKIP, pay_period_details: SKIP, additional_properties: nil) ⇒ PaystubOverride
Returns a new instance of PaystubOverride.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/plaid/models/paystub_override.rb', line 53 def initialize(employer: SKIP, employee: SKIP, income_breakdown: SKIP, pay_period_details: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @employer = employer unless employer == SKIP @employee = employee unless employee == SKIP @income_breakdown = income_breakdown unless income_breakdown == SKIP @pay_period_details = pay_period_details unless pay_period_details == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#employee ⇒ Employee2
The employee on the paystub.
18 19 20 |
# File 'lib/plaid/models/paystub_override.rb', line 18 def employee @employee end |
#employer ⇒ Employer3
The employer on the paystub.
14 15 16 |
# File 'lib/plaid/models/paystub_override.rb', line 14 def employer @employer end |
#income_breakdown ⇒ Array[IncomeBreakdown]
The employee on the paystub.
22 23 24 |
# File 'lib/plaid/models/paystub_override.rb', line 22 def income_breakdown @income_breakdown end |
#pay_period_details ⇒ PayPeriodDetails
Details about the pay period.
26 27 28 |
# File 'lib/plaid/models/paystub_override.rb', line 26 def pay_period_details @pay_period_details end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/plaid/models/paystub_override.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. employer = Employer3.from_hash(hash['employer']) if hash['employer'] employee = Employee2.from_hash(hash['employee']) if hash['employee'] # Parameter is an array, so we need to iterate through it income_breakdown = nil unless hash['income_breakdown'].nil? income_breakdown = [] hash['income_breakdown'].each do |structure| income_breakdown << (IncomeBreakdown.from_hash(structure) if structure) end end income_breakdown = SKIP unless hash.key?('income_breakdown') pay_period_details = PayPeriodDetails.from_hash(hash['pay_period_details']) if hash['pay_period_details'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaystubOverride.new(employer: employer, employee: employee, income_breakdown: income_breakdown, pay_period_details: pay_period_details, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/plaid/models/paystub_override.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['employer'] = 'employer' @_hash['employee'] = 'employee' @_hash['income_breakdown'] = 'income_breakdown' @_hash['pay_period_details'] = 'pay_period_details' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/plaid/models/paystub_override.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/plaid/models/paystub_override.rb', line 39 def self.optionals %w[ employer employee income_breakdown pay_period_details ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
109 110 111 112 113 114 |
# File 'lib/plaid/models/paystub_override.rb', line 109 def inspect class_name = self.class.name.split('::').last "<#{class_name} employer: #{@employer.inspect}, employee: #{@employee.inspect},"\ " income_breakdown: #{@income_breakdown.inspect}, pay_period_details:"\ " #{@pay_period_details.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
101 102 103 104 105 106 |
# File 'lib/plaid/models/paystub_override.rb', line 101 def to_s class_name = self.class.name.split('::').last "<#{class_name} employer: #{@employer}, employee: #{@employee}, income_breakdown:"\ " #{@income_breakdown}, pay_period_details: #{@pay_period_details}, additional_properties:"\ " #{@additional_properties}>" end |