Class: Plaid::ProcessorNumber
- Defined in:
- lib/plaid/models/processor_number.rb
Overview
An object containing identifying numbers used for making electronic transfers to and from the ‘account`. The identifying number type (ACH, EFT, IBAN, or BACS) used will depend on the country of the account. An account may have more than one number type. If a particular identifying number type is not used by the `account` for which auth data has been requested, a null value will be returned.
Instance Attribute Summary collapse
-
#ach ⇒ NumbersAchNullable
TODO: Write general description for this method.
-
#bacs ⇒ NumbersBacsNullable
TODO: Write general description for this method.
-
#eft ⇒ NumbersEftNullable
TODO: Write general description for this method.
-
#international ⇒ NumbersInternationalNullable
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ach: SKIP, eft: SKIP, international: SKIP, bacs: SKIP, additional_properties: nil) ⇒ ProcessorNumber
constructor
A new instance of ProcessorNumber.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ach: SKIP, eft: SKIP, international: SKIP, bacs: SKIP, additional_properties: nil) ⇒ ProcessorNumber
Returns a new instance of ProcessorNumber.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/plaid/models/processor_number.rb', line 58 def initialize(ach: SKIP, eft: SKIP, international: SKIP, bacs: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @ach = ach unless ach == SKIP @eft = eft unless eft == SKIP @international = international unless international == SKIP @bacs = bacs unless bacs == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#ach ⇒ NumbersAchNullable
TODO: Write general description for this method
19 20 21 |
# File 'lib/plaid/models/processor_number.rb', line 19 def ach @ach end |
#bacs ⇒ NumbersBacsNullable
TODO: Write general description for this method
31 32 33 |
# File 'lib/plaid/models/processor_number.rb', line 31 def bacs @bacs end |
#eft ⇒ NumbersEftNullable
TODO: Write general description for this method
23 24 25 |
# File 'lib/plaid/models/processor_number.rb', line 23 def eft @eft end |
#international ⇒ NumbersInternationalNullable
TODO: Write general description for this method
27 28 29 |
# File 'lib/plaid/models/processor_number.rb', line 27 def international @international end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/plaid/models/processor_number.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ach = NumbersAchNullable.from_hash(hash['ach']) if hash['ach'] eft = NumbersEftNullable.from_hash(hash['eft']) if hash['eft'] international = NumbersInternationalNullable.from_hash(hash['international']) if hash['international'] bacs = NumbersBacsNullable.from_hash(hash['bacs']) if hash['bacs'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorNumber.new(ach: ach, eft: eft, international: international, bacs: bacs, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 |
# File 'lib/plaid/models/processor_number.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['ach'] = 'ach' @_hash['eft'] = 'eft' @_hash['international'] = 'international' @_hash['bacs'] = 'bacs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/plaid/models/processor_number.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 |
# File 'lib/plaid/models/processor_number.rb', line 44 def self.optionals %w[ ach eft international bacs ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/plaid/models/processor_number.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} ach: #{@ach.inspect}, eft: #{@eft.inspect}, international:"\ " #{@international.inspect}, bacs: #{@bacs.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/plaid/models/processor_number.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} ach: #{@ach}, eft: #{@eft}, international: #{@international}, bacs:"\ " #{@bacs}, additional_properties: #{@additional_properties}>" end |