Class: Plaid::SandboxIncomeFireWebhookRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::SandboxIncomeFireWebhookRequest
- Defined in:
- lib/plaid/models/sandbox_income_fire_webhook_request.rb
Overview
SandboxIncomeFireWebhookRequest defines the request schema for ‘/sandbox/income/fire_webhook`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#income_verification_id ⇒ String
The ID of the verification.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#verification_status ⇒ VerificationStatus3
‘VERIFICATION_STATUS_PROCESSING_COMPLETE`: The income verification status processing has completed.
-
#webhook ⇒ String
The URL to which the webhook should be sent.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(income_verification_id:, webhook:, verification_status:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ SandboxIncomeFireWebhookRequest
constructor
A new instance of SandboxIncomeFireWebhookRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(income_verification_id:, webhook:, verification_status:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ SandboxIncomeFireWebhookRequest
Returns a new instance of SandboxIncomeFireWebhookRequest.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 66 def initialize(income_verification_id:, webhook:, verification_status:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @income_verification_id = income_verification_id @webhook = webhook @verification_status = verification_status @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 17 def client_id @client_id end |
#income_verification_id ⇒ String
The ID of the verification.
26 27 28 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 26 def income_verification_id @income_verification_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 22 def secret @secret end |
#verification_status ⇒ VerificationStatus3
‘VERIFICATION_STATUS_PROCESSING_COMPLETE`: The income verification status processing has completed. `VERIFICATION_STATUS_DOCUMENT_REJECTED`: The documentation uploaded by the end user was recognized as a supported file format, but not recognized as a valid paystub. `VERIFICATION_STATUS_PROCESSING_FAILED`: A failure occurred when attempting to process the verification documentation.
40 41 42 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 40 def verification_status @verification_status end |
#webhook ⇒ String
The URL to which the webhook should be sent.
30 31 32 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 30 def webhook @webhook end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 80 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. income_verification_id = hash.key?('income_verification_id') ? hash['income_verification_id'] : nil webhook = hash.key?('webhook') ? hash['webhook'] : nil verification_status = hash.key?('verification_status') ? hash['verification_status'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxIncomeFireWebhookRequest.new(income_verification_id: income_verification_id, webhook: webhook, verification_status: verification_status, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
43 44 45 46 47 48 49 50 51 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 43 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['income_verification_id'] = 'income_verification_id' @_hash['webhook'] = 'webhook' @_hash['verification_status'] = 'verification_status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
62 63 64 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 62 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 54 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
117 118 119 120 121 122 123 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 117 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " income_verification_id: #{@income_verification_id.inspect}, webhook: #{@webhook.inspect},"\ " verification_status: #{@verification_status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
109 110 111 112 113 114 |
# File 'lib/plaid/models/sandbox_income_fire_webhook_request.rb', line 109 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, income_verification_id:"\ " #{@income_verification_id}, webhook: #{@webhook}, verification_status:"\ " #{@verification_status}, additional_properties: #{@additional_properties}>" end |