Class: Plaid::SandboxPublicTokenCreateRequestOptionsTransactions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::SandboxPublicTokenCreateRequestOptionsTransactions
- Defined in:
- lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb
Overview
SandboxPublicTokenCreateRequestOptionsTransactions is an optional set of parameters corresponding to transactions options.
Instance Attribute Summary collapse
-
#end_date ⇒ Date
The most recent date for which to fetch transaction history.
-
#start_date ⇒ Date
The earliest date for which to fetch transaction history.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_date: SKIP, end_date: SKIP, additional_properties: nil) ⇒ SandboxPublicTokenCreateRequestOptionsTransactions
constructor
A new instance of SandboxPublicTokenCreateRequestOptionsTransactions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_date: SKIP, end_date: SKIP, additional_properties: nil) ⇒ SandboxPublicTokenCreateRequestOptionsTransactions
Returns a new instance of SandboxPublicTokenCreateRequestOptionsTransactions.
44 45 46 47 48 49 50 51 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 44 def initialize(start_date: SKIP, end_date: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_date = start_date unless start_date == SKIP @end_date = end_date unless end_date == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#end_date ⇒ Date
The most recent date for which to fetch transaction history. Dates should be formatted as YYYY-MM-DD.
21 22 23 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 21 def end_date @end_date end |
#start_date ⇒ Date
The earliest date for which to fetch transaction history. Dates should be formatted as YYYY-MM-DD.
16 17 18 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 16 def start_date @start_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_date = hash.key?('start_date') ? hash['start_date'] : SKIP end_date = hash.key?('end_date') ? hash['end_date'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxPublicTokenCreateRequestOptionsTransactions.new(start_date: start_date, end_date: end_date, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 32 def self.optionals %w[ start_date end_date ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/plaid/models/sandbox_public_token_create_request_options_transactions.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, additional_properties:"\ " #{@additional_properties}>" end |