Class: Plaid::SignalEvaluateCoreAttributes

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/signal_evaluate_core_attributes.rb

Overview

The core attributes object contains additional data that can be used to assess the ACH return risk, such as past ACH return events, balance/transaction history, the Item’s connection history in the Plaid network, and identity change history.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(unauthorized_transactions_count_7d: SKIP, unauthorized_transactions_count_30d: SKIP, unauthorized_transactions_count_60d: SKIP, unauthorized_transactions_count_90d: SKIP, nsf_overdraft_transactions_count_7d: SKIP, nsf_overdraft_transactions_count_30d: SKIP, nsf_overdraft_transactions_count_60d: SKIP, nsf_overdraft_transactions_count_90d: SKIP, days_since_first_plaid_connection: SKIP, plaid_connections_count_7d: SKIP, plaid_connections_count_30d: SKIP, total_plaid_connections_count: SKIP, is_savings_or_money_market_account: SKIP, total_credit_transactions_amount_10d: SKIP, total_debit_transactions_amount_10d: SKIP, p50_credit_transactions_amount_28d: SKIP, p50_debit_transactions_amount_28d: SKIP, p95_credit_transactions_amount_28d: SKIP, p95_debit_transactions_amount_28d: SKIP, days_with_negative_balance_count_90d: SKIP, p90_eod_balance_30d: SKIP, p90_eod_balance_60d: SKIP, p90_eod_balance_90d: SKIP, p10_eod_balance_30d: SKIP, p10_eod_balance_60d: SKIP, p10_eod_balance_90d: SKIP, available_balance: SKIP, current_balance: SKIP, balance_last_updated: SKIP, phone_change_count_28d: SKIP, phone_change_count_90d: SKIP, email_change_count_28d: SKIP, email_change_count_90d: SKIP, address_change_count_28d: SKIP, address_change_count_90d: SKIP, additional_properties: nil) ⇒ SignalEvaluateCoreAttributes

Returns a new instance of SignalEvaluateCoreAttributes.



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 331

def initialize(unauthorized_transactions_count_7d: SKIP,
               unauthorized_transactions_count_30d: SKIP,
               unauthorized_transactions_count_60d: SKIP,
               unauthorized_transactions_count_90d: SKIP,
               nsf_overdraft_transactions_count_7d: SKIP,
               nsf_overdraft_transactions_count_30d: SKIP,
               nsf_overdraft_transactions_count_60d: SKIP,
               nsf_overdraft_transactions_count_90d: SKIP,
               days_since_first_plaid_connection: SKIP,
               plaid_connections_count_7d: SKIP,
               plaid_connections_count_30d: SKIP,
               total_plaid_connections_count: SKIP,
               is_savings_or_money_market_account: SKIP,
               total_credit_transactions_amount_10d: SKIP,
               total_debit_transactions_amount_10d: SKIP,
               p50_credit_transactions_amount_28d: SKIP,
               p50_debit_transactions_amount_28d: SKIP,
               p95_credit_transactions_amount_28d: SKIP,
               p95_debit_transactions_amount_28d: SKIP,
               days_with_negative_balance_count_90d: SKIP,
               p90_eod_balance_30d: SKIP, p90_eod_balance_60d: SKIP,
               p90_eod_balance_90d: SKIP, p10_eod_balance_30d: SKIP,
               p10_eod_balance_60d: SKIP, p10_eod_balance_90d: SKIP,
               available_balance: SKIP, current_balance: SKIP,
               balance_last_updated: SKIP, phone_change_count_28d: SKIP,
               phone_change_count_90d: SKIP, email_change_count_28d: SKIP,
               email_change_count_90d: SKIP, address_change_count_28d: SKIP,
               address_change_count_90d: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless unauthorized_transactions_count_7d == SKIP
    @unauthorized_transactions_count_7d =
      unauthorized_transactions_count_7d
  end
  unless unauthorized_transactions_count_30d == SKIP
    @unauthorized_transactions_count_30d =
      unauthorized_transactions_count_30d
  end
  unless unauthorized_transactions_count_60d == SKIP
    @unauthorized_transactions_count_60d =
      unauthorized_transactions_count_60d
  end
  unless unauthorized_transactions_count_90d == SKIP
    @unauthorized_transactions_count_90d =
      unauthorized_transactions_count_90d
  end
  unless nsf_overdraft_transactions_count_7d == SKIP
    @nsf_overdraft_transactions_count_7d =
      nsf_overdraft_transactions_count_7d
  end
  unless nsf_overdraft_transactions_count_30d == SKIP
    @nsf_overdraft_transactions_count_30d =
      nsf_overdraft_transactions_count_30d
  end
  unless nsf_overdraft_transactions_count_60d == SKIP
    @nsf_overdraft_transactions_count_60d =
      nsf_overdraft_transactions_count_60d
  end
  unless nsf_overdraft_transactions_count_90d == SKIP
    @nsf_overdraft_transactions_count_90d =
      nsf_overdraft_transactions_count_90d
  end
  unless days_since_first_plaid_connection == SKIP
    @days_since_first_plaid_connection =
      days_since_first_plaid_connection
  end
  unless plaid_connections_count_7d == SKIP
    @plaid_connections_count_7d =
      plaid_connections_count_7d
  end
  unless plaid_connections_count_30d == SKIP
    @plaid_connections_count_30d =
      plaid_connections_count_30d
  end
  unless total_plaid_connections_count == SKIP
    @total_plaid_connections_count =
      total_plaid_connections_count
  end
  unless  == SKIP
    @is_savings_or_money_market_account =
      
  end
  unless total_credit_transactions_amount_10d == SKIP
    @total_credit_transactions_amount_10d =
      total_credit_transactions_amount_10d
  end
  unless total_debit_transactions_amount_10d == SKIP
    @total_debit_transactions_amount_10d =
      total_debit_transactions_amount_10d
  end
  unless p50_credit_transactions_amount_28d == SKIP
    @p50_credit_transactions_amount_28d =
      p50_credit_transactions_amount_28d
  end
  unless p50_debit_transactions_amount_28d == SKIP
    @p50_debit_transactions_amount_28d =
      p50_debit_transactions_amount_28d
  end
  unless p95_credit_transactions_amount_28d == SKIP
    @p95_credit_transactions_amount_28d =
      p95_credit_transactions_amount_28d
  end
  unless p95_debit_transactions_amount_28d == SKIP
    @p95_debit_transactions_amount_28d =
      p95_debit_transactions_amount_28d
  end
  unless days_with_negative_balance_count_90d == SKIP
    @days_with_negative_balance_count_90d =
      days_with_negative_balance_count_90d
  end
  @p90_eod_balance_30d = p90_eod_balance_30d unless p90_eod_balance_30d == SKIP
  @p90_eod_balance_60d = p90_eod_balance_60d unless p90_eod_balance_60d == SKIP
  @p90_eod_balance_90d = p90_eod_balance_90d unless p90_eod_balance_90d == SKIP
  @p10_eod_balance_30d = p10_eod_balance_30d unless p10_eod_balance_30d == SKIP
  @p10_eod_balance_60d = p10_eod_balance_60d unless p10_eod_balance_60d == SKIP
  @p10_eod_balance_90d = p10_eod_balance_90d unless p10_eod_balance_90d == SKIP
  @available_balance = available_balance unless available_balance == SKIP
  @current_balance = current_balance unless current_balance == SKIP
  @balance_last_updated = balance_last_updated unless balance_last_updated == SKIP
  @phone_change_count_28d = phone_change_count_28d unless phone_change_count_28d == SKIP
  @phone_change_count_90d = phone_change_count_90d unless phone_change_count_90d == SKIP
  @email_change_count_28d = email_change_count_28d unless email_change_count_28d == SKIP
  @email_change_count_90d = email_change_count_90d unless email_change_count_90d == SKIP
  @address_change_count_28d = address_change_count_28d unless address_change_count_28d == SKIP
  @address_change_count_90d = address_change_count_90d unless address_change_count_90d == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#address_change_count_28dInteger

The number of times the account’s addresses on file have changed over the past 28 days

Returns:

  • (Integer)


194
195
196
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 194

def address_change_count_28d
  @address_change_count_28d
end

#address_change_count_90dInteger

The number of times the account’s addresses on file have changed over the past 90 days

Returns:

  • (Integer)


199
200
201
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 199

def address_change_count_90d
  @address_change_count_90d
end

#available_balanceFloat

Available balance, as of the ‘balance_last_updated` time. The available balance is the current balance less any outstanding holds or debits that have not yet posted to the account.

Returns:

  • (Float)


158
159
160
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 158

def available_balance
  @available_balance
end

#balance_last_updatedDateTime

Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (YYYY-MM-DDTHH:mm:ssZ) indicating the last time that the balance for the given account has been updated.

Returns:

  • (DateTime)


169
170
171
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 169

def balance_last_updated
  @balance_last_updated
end

#current_balanceFloat

Current balance, as of the ‘balance_last_updated` time. The current balance is the total amount of funds in the account.

Returns:

  • (Float)


163
164
165
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 163

def current_balance
  @current_balance
end

#days_since_first_plaid_connectionInteger

The number of days since the first time the Item was connected to an application via Plaid

Returns:

  • (Integer)


67
68
69
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 67

def days_since_first_plaid_connection
  @days_since_first_plaid_connection
end

#days_with_negative_balance_count_90dInteger

The number of days within the past 90 days when the account that will be debited had a negative end-of-day available balance

Returns:

  • (Integer)


122
123
124
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 122

def days_with_negative_balance_count_90d
  @days_with_negative_balance_count_90d
end

#email_change_count_28dInteger

The number of times the account’s email addresses on file have changed over the past 28 days

Returns:

  • (Integer)


184
185
186
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 184

def email_change_count_28d
  @email_change_count_28d
end

#email_change_count_90dInteger

The number of times the account’s email addresses on file have changed over the past 90 days

Returns:

  • (Integer)


189
190
191
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 189

def email_change_count_90d
  @email_change_count_90d
end

#is_savings_or_money_market_accountTrueClass | FalseClass

Indicates if the ACH transaction funding account is a savings/money market account

Returns:

  • (TrueClass | FalseClass)


87
88
89
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 87

def 
  @is_savings_or_money_market_account
end

#nsf_overdraft_transactions_count_30dInteger

We parse and analyze historical transaction metadata to identify the number of possible past returns due to non-sufficient funds/overdrafts over the past 30 days from the account that will be debited.

Returns:

  • (Integer)


50
51
52
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 50

def nsf_overdraft_transactions_count_30d
  @nsf_overdraft_transactions_count_30d
end

#nsf_overdraft_transactions_count_60dInteger

We parse and analyze historical transaction metadata to identify the number of possible past returns due to non-sufficient funds/overdrafts over the past 60 days from the account that will be debited.

Returns:

  • (Integer)


56
57
58
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 56

def nsf_overdraft_transactions_count_60d
  @nsf_overdraft_transactions_count_60d
end

#nsf_overdraft_transactions_count_7dInteger

We parse and analyze historical transaction metadata to identify the number of possible past returns due to non-sufficient funds/overdrafts over the past 7 days from the account that will be debited.

Returns:

  • (Integer)


44
45
46
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 44

def nsf_overdraft_transactions_count_7d
  @nsf_overdraft_transactions_count_7d
end

#nsf_overdraft_transactions_count_90dInteger

We parse and analyze historical transaction metadata to identify the number of possible past returns due to non-sufficient funds/overdrafts over the past 90 days from the account that will be debited.

Returns:

  • (Integer)


62
63
64
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 62

def nsf_overdraft_transactions_count_90d
  @nsf_overdraft_transactions_count_90d
end

#p10_eod_balance_30dFloat

The 10th percentile of the end-of-day available balance over the past 30 days of the account that will be debited

Returns:

  • (Float)


142
143
144
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 142

def p10_eod_balance_30d
  @p10_eod_balance_30d
end

#p10_eod_balance_60dFloat

The 10th percentile of the end-of-day available balance over the past 60 days of the account that will be debited

Returns:

  • (Float)


147
148
149
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 147

def p10_eod_balance_60d
  @p10_eod_balance_60d
end

#p10_eod_balance_90dFloat

The 10th percentile of the end-of-day available balance over the past 90 days of the account that will be debited

Returns:

  • (Float)


152
153
154
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 152

def p10_eod_balance_90d
  @p10_eod_balance_90d
end

#p50_credit_transactions_amount_28dFloat

The 50th percentile of all credit (inflow) transaction amounts over the past 28 days from the account that will be debited

Returns:

  • (Float)


102
103
104
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 102

def p50_credit_transactions_amount_28d
  @p50_credit_transactions_amount_28d
end

#p50_debit_transactions_amount_28dFloat

The 50th percentile of all debit (outflow) transaction amounts over the past 28 days from the account that will be debited

Returns:

  • (Float)


107
108
109
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 107

def p50_debit_transactions_amount_28d
  @p50_debit_transactions_amount_28d
end

#p90_eod_balance_30dFloat

The 90th percentile of the end-of-day available balance over the past 30 days of the account that will be debited

Returns:

  • (Float)


127
128
129
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 127

def p90_eod_balance_30d
  @p90_eod_balance_30d
end

#p90_eod_balance_60dFloat

The 90th percentile of the end-of-day available balance over the past 60 days of the account that will be debited

Returns:

  • (Float)


132
133
134
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 132

def p90_eod_balance_60d
  @p90_eod_balance_60d
end

#p90_eod_balance_90dFloat

The 90th percentile of the end-of-day available balance over the past 90 days of the account that will be debited

Returns:

  • (Float)


137
138
139
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 137

def p90_eod_balance_90d
  @p90_eod_balance_90d
end

#p95_credit_transactions_amount_28dFloat

The 95th percentile of all credit (inflow) transaction amounts over the past 28 days from the account that will be debited

Returns:

  • (Float)


112
113
114
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 112

def p95_credit_transactions_amount_28d
  @p95_credit_transactions_amount_28d
end

#p95_debit_transactions_amount_28dFloat

The 95th percentile of all debit (outflow) transaction amounts over the past 28 days from the account that will be debited

Returns:

  • (Float)


117
118
119
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 117

def p95_debit_transactions_amount_28d
  @p95_debit_transactions_amount_28d
end

#phone_change_count_28dInteger

The number of times the account’s phone numbers on file have changed over the past 28 days

Returns:

  • (Integer)


174
175
176
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 174

def phone_change_count_28d
  @phone_change_count_28d
end

#phone_change_count_90dInteger

The number of times the account’s phone numbers on file have changed over the past 90 days

Returns:

  • (Integer)


179
180
181
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 179

def phone_change_count_90d
  @phone_change_count_90d
end

#plaid_connections_count_30dInteger

The number of times the Item has been connected to applications via Plaid over the past 30 days

Returns:

  • (Integer)


77
78
79
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 77

def plaid_connections_count_30d
  @plaid_connections_count_30d
end

#plaid_connections_count_7dInteger

The number of times the Item has been connected to applications via Plaid over the past 7 days

Returns:

  • (Integer)


72
73
74
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 72

def plaid_connections_count_7d
  @plaid_connections_count_7d
end

#total_credit_transactions_amount_10dFloat

The total credit (inflow) transaction amount over the past 10 days from the account that will be debited

Returns:

  • (Float)


92
93
94
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 92

def total_credit_transactions_amount_10d
  @total_credit_transactions_amount_10d
end

#total_debit_transactions_amount_10dFloat

The total debit (outflow) transaction amount over the past 10 days from the account that will be debited

Returns:

  • (Float)


97
98
99
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 97

def total_debit_transactions_amount_10d
  @total_debit_transactions_amount_10d
end

#total_plaid_connections_countInteger

The total number of times the Item has been connected to applications via Plaid

Returns:

  • (Integer)


82
83
84
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 82

def total_plaid_connections_count
  @total_plaid_connections_count
end

#unauthorized_transactions_count_30dInteger

We parse and analyze historical transaction metadata to identify the number of possible past returns due to unauthorized transactions over the past 30 days from the account that will be debited.

Returns:

  • (Integer)


26
27
28
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 26

def unauthorized_transactions_count_30d
  @unauthorized_transactions_count_30d
end

#unauthorized_transactions_count_60dInteger

We parse and analyze historical transaction metadata to identify the number of possible past returns due to unauthorized transactions over the past 60 days from the account that will be debited.

Returns:

  • (Integer)


32
33
34
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 32

def unauthorized_transactions_count_60d
  @unauthorized_transactions_count_60d
end

#unauthorized_transactions_count_7dInteger

We parse and analyze historical transaction metadata to identify the number of possible past returns due to unauthorized transactions over the past 7 days from the account that will be debited.

Returns:

  • (Integer)


20
21
22
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 20

def unauthorized_transactions_count_7d
  @unauthorized_transactions_count_7d
end

#unauthorized_transactions_count_90dInteger

We parse and analyze historical transaction metadata to identify the number of possible past returns due to unauthorized transactions over the past 90 days from the account that will be debited.

Returns:

  • (Integer)


38
39
40
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 38

def unauthorized_transactions_count_90d
  @unauthorized_transactions_count_90d
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 461

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  unauthorized_transactions_count_7d =
    hash.key?('unauthorized_transactions_count_7d') ? hash['unauthorized_transactions_count_7d'] : SKIP
  unauthorized_transactions_count_30d =
    hash.key?('unauthorized_transactions_count_30d') ? hash['unauthorized_transactions_count_30d'] : SKIP
  unauthorized_transactions_count_60d =
    hash.key?('unauthorized_transactions_count_60d') ? hash['unauthorized_transactions_count_60d'] : SKIP
  unauthorized_transactions_count_90d =
    hash.key?('unauthorized_transactions_count_90d') ? hash['unauthorized_transactions_count_90d'] : SKIP
  nsf_overdraft_transactions_count_7d =
    hash.key?('nsf_overdraft_transactions_count_7d') ? hash['nsf_overdraft_transactions_count_7d'] : SKIP
  nsf_overdraft_transactions_count_30d =
    hash.key?('nsf_overdraft_transactions_count_30d') ? hash['nsf_overdraft_transactions_count_30d'] : SKIP
  nsf_overdraft_transactions_count_60d =
    hash.key?('nsf_overdraft_transactions_count_60d') ? hash['nsf_overdraft_transactions_count_60d'] : SKIP
  nsf_overdraft_transactions_count_90d =
    hash.key?('nsf_overdraft_transactions_count_90d') ? hash['nsf_overdraft_transactions_count_90d'] : SKIP
  days_since_first_plaid_connection =
    hash.key?('days_since_first_plaid_connection') ? hash['days_since_first_plaid_connection'] : SKIP
  plaid_connections_count_7d =
    hash.key?('plaid_connections_count_7d') ? hash['plaid_connections_count_7d'] : SKIP
  plaid_connections_count_30d =
    hash.key?('plaid_connections_count_30d') ? hash['plaid_connections_count_30d'] : SKIP
  total_plaid_connections_count =
    hash.key?('total_plaid_connections_count') ? hash['total_plaid_connections_count'] : SKIP
   =
    hash.key?('is_savings_or_money_market_account') ? hash['is_savings_or_money_market_account'] : SKIP
  total_credit_transactions_amount_10d =
    hash.key?('total_credit_transactions_amount_10d') ? hash['total_credit_transactions_amount_10d'] : SKIP
  total_debit_transactions_amount_10d =
    hash.key?('total_debit_transactions_amount_10d') ? hash['total_debit_transactions_amount_10d'] : SKIP
  p50_credit_transactions_amount_28d =
    hash.key?('p50_credit_transactions_amount_28d') ? hash['p50_credit_transactions_amount_28d'] : SKIP
  p50_debit_transactions_amount_28d =
    hash.key?('p50_debit_transactions_amount_28d') ? hash['p50_debit_transactions_amount_28d'] : SKIP
  p95_credit_transactions_amount_28d =
    hash.key?('p95_credit_transactions_amount_28d') ? hash['p95_credit_transactions_amount_28d'] : SKIP
  p95_debit_transactions_amount_28d =
    hash.key?('p95_debit_transactions_amount_28d') ? hash['p95_debit_transactions_amount_28d'] : SKIP
  days_with_negative_balance_count_90d =
    hash.key?('days_with_negative_balance_count_90d') ? hash['days_with_negative_balance_count_90d'] : SKIP
  p90_eod_balance_30d =
    hash.key?('p90_eod_balance_30d') ? hash['p90_eod_balance_30d'] : SKIP
  p90_eod_balance_60d =
    hash.key?('p90_eod_balance_60d') ? hash['p90_eod_balance_60d'] : SKIP
  p90_eod_balance_90d =
    hash.key?('p90_eod_balance_90d') ? hash['p90_eod_balance_90d'] : SKIP
  p10_eod_balance_30d =
    hash.key?('p10_eod_balance_30d') ? hash['p10_eod_balance_30d'] : SKIP
  p10_eod_balance_60d =
    hash.key?('p10_eod_balance_60d') ? hash['p10_eod_balance_60d'] : SKIP
  p10_eod_balance_90d =
    hash.key?('p10_eod_balance_90d') ? hash['p10_eod_balance_90d'] : SKIP
  available_balance =
    hash.key?('available_balance') ? hash['available_balance'] : SKIP
  current_balance =
    hash.key?('current_balance') ? hash['current_balance'] : SKIP
  balance_last_updated = if hash.key?('balance_last_updated')
                           (DateTimeHelper.from_rfc3339(hash['balance_last_updated']) if hash['balance_last_updated'])
                         else
                           SKIP
                         end
  phone_change_count_28d =
    hash.key?('phone_change_count_28d') ? hash['phone_change_count_28d'] : SKIP
  phone_change_count_90d =
    hash.key?('phone_change_count_90d') ? hash['phone_change_count_90d'] : SKIP
  email_change_count_28d =
    hash.key?('email_change_count_28d') ? hash['email_change_count_28d'] : SKIP
  email_change_count_90d =
    hash.key?('email_change_count_90d') ? hash['email_change_count_90d'] : SKIP
  address_change_count_28d =
    hash.key?('address_change_count_28d') ? hash['address_change_count_28d'] : SKIP
  address_change_count_90d =
    hash.key?('address_change_count_90d') ? hash['address_change_count_90d'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SignalEvaluateCoreAttributes.new(unauthorized_transactions_count_7d: unauthorized_transactions_count_7d,
                                   unauthorized_transactions_count_30d: unauthorized_transactions_count_30d,
                                   unauthorized_transactions_count_60d: unauthorized_transactions_count_60d,
                                   unauthorized_transactions_count_90d: unauthorized_transactions_count_90d,
                                   nsf_overdraft_transactions_count_7d: nsf_overdraft_transactions_count_7d,
                                   nsf_overdraft_transactions_count_30d: nsf_overdraft_transactions_count_30d,
                                   nsf_overdraft_transactions_count_60d: nsf_overdraft_transactions_count_60d,
                                   nsf_overdraft_transactions_count_90d: nsf_overdraft_transactions_count_90d,
                                   days_since_first_plaid_connection: days_since_first_plaid_connection,
                                   plaid_connections_count_7d: plaid_connections_count_7d,
                                   plaid_connections_count_30d: plaid_connections_count_30d,
                                   total_plaid_connections_count: total_plaid_connections_count,
                                   is_savings_or_money_market_account: ,
                                   total_credit_transactions_amount_10d: total_credit_transactions_amount_10d,
                                   total_debit_transactions_amount_10d: total_debit_transactions_amount_10d,
                                   p50_credit_transactions_amount_28d: p50_credit_transactions_amount_28d,
                                   p50_debit_transactions_amount_28d: p50_debit_transactions_amount_28d,
                                   p95_credit_transactions_amount_28d: p95_credit_transactions_amount_28d,
                                   p95_debit_transactions_amount_28d: p95_debit_transactions_amount_28d,
                                   days_with_negative_balance_count_90d: days_with_negative_balance_count_90d,
                                   p90_eod_balance_30d: p90_eod_balance_30d,
                                   p90_eod_balance_60d: p90_eod_balance_60d,
                                   p90_eod_balance_90d: p90_eod_balance_90d,
                                   p10_eod_balance_30d: p10_eod_balance_30d,
                                   p10_eod_balance_60d: p10_eod_balance_60d,
                                   p10_eod_balance_90d: p10_eod_balance_90d,
                                   available_balance: available_balance,
                                   current_balance: current_balance,
                                   balance_last_updated: balance_last_updated,
                                   phone_change_count_28d: phone_change_count_28d,
                                   phone_change_count_90d: phone_change_count_90d,
                                   email_change_count_28d: email_change_count_28d,
                                   email_change_count_90d: email_change_count_90d,
                                   address_change_count_28d: address_change_count_28d,
                                   address_change_count_90d: address_change_count_90d,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 202

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['unauthorized_transactions_count_7d'] =
    'unauthorized_transactions_count_7d'
  @_hash['unauthorized_transactions_count_30d'] =
    'unauthorized_transactions_count_30d'
  @_hash['unauthorized_transactions_count_60d'] =
    'unauthorized_transactions_count_60d'
  @_hash['unauthorized_transactions_count_90d'] =
    'unauthorized_transactions_count_90d'
  @_hash['nsf_overdraft_transactions_count_7d'] =
    'nsf_overdraft_transactions_count_7d'
  @_hash['nsf_overdraft_transactions_count_30d'] =
    'nsf_overdraft_transactions_count_30d'
  @_hash['nsf_overdraft_transactions_count_60d'] =
    'nsf_overdraft_transactions_count_60d'
  @_hash['nsf_overdraft_transactions_count_90d'] =
    'nsf_overdraft_transactions_count_90d'
  @_hash['days_since_first_plaid_connection'] =
    'days_since_first_plaid_connection'
  @_hash['plaid_connections_count_7d'] = 'plaid_connections_count_7d'
  @_hash['plaid_connections_count_30d'] = 'plaid_connections_count_30d'
  @_hash['total_plaid_connections_count'] =
    'total_plaid_connections_count'
  @_hash['is_savings_or_money_market_account'] =
    'is_savings_or_money_market_account'
  @_hash['total_credit_transactions_amount_10d'] =
    'total_credit_transactions_amount_10d'
  @_hash['total_debit_transactions_amount_10d'] =
    'total_debit_transactions_amount_10d'
  @_hash['p50_credit_transactions_amount_28d'] =
    'p50_credit_transactions_amount_28d'
  @_hash['p50_debit_transactions_amount_28d'] =
    'p50_debit_transactions_amount_28d'
  @_hash['p95_credit_transactions_amount_28d'] =
    'p95_credit_transactions_amount_28d'
  @_hash['p95_debit_transactions_amount_28d'] =
    'p95_debit_transactions_amount_28d'
  @_hash['days_with_negative_balance_count_90d'] =
    'days_with_negative_balance_count_90d'
  @_hash['p90_eod_balance_30d'] = 'p90_eod_balance_30d'
  @_hash['p90_eod_balance_60d'] = 'p90_eod_balance_60d'
  @_hash['p90_eod_balance_90d'] = 'p90_eod_balance_90d'
  @_hash['p10_eod_balance_30d'] = 'p10_eod_balance_30d'
  @_hash['p10_eod_balance_60d'] = 'p10_eod_balance_60d'
  @_hash['p10_eod_balance_90d'] = 'p10_eod_balance_90d'
  @_hash['available_balance'] = 'available_balance'
  @_hash['current_balance'] = 'current_balance'
  @_hash['balance_last_updated'] = 'balance_last_updated'
  @_hash['phone_change_count_28d'] = 'phone_change_count_28d'
  @_hash['phone_change_count_90d'] = 'phone_change_count_90d'
  @_hash['email_change_count_28d'] = 'email_change_count_28d'
  @_hash['email_change_count_90d'] = 'email_change_count_90d'
  @_hash['address_change_count_28d'] = 'address_change_count_28d'
  @_hash['address_change_count_90d'] = 'address_change_count_90d'
  @_hash
end

.nullablesObject

An array for nullable fields



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 302

def self.nullables
  %w[
    days_since_first_plaid_connection
    plaid_connections_count_7d
    plaid_connections_count_30d
    total_plaid_connections_count
    p50_credit_transactions_amount_28d
    p50_debit_transactions_amount_28d
    p95_credit_transactions_amount_28d
    p95_debit_transactions_amount_28d
    days_with_negative_balance_count_90d
    p90_eod_balance_30d
    p90_eod_balance_60d
    p90_eod_balance_90d
    p10_eod_balance_30d
    p10_eod_balance_60d
    p10_eod_balance_90d
    available_balance
    current_balance
    balance_last_updated
    phone_change_count_28d
    phone_change_count_90d
    email_change_count_28d
    email_change_count_90d
    address_change_count_28d
    address_change_count_90d
  ]
end

.optionalsObject

An array for optional fields



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 261

def self.optionals
  %w[
    unauthorized_transactions_count_7d
    unauthorized_transactions_count_30d
    unauthorized_transactions_count_60d
    unauthorized_transactions_count_90d
    nsf_overdraft_transactions_count_7d
    nsf_overdraft_transactions_count_30d
    nsf_overdraft_transactions_count_60d
    nsf_overdraft_transactions_count_90d
    days_since_first_plaid_connection
    plaid_connections_count_7d
    plaid_connections_count_30d
    total_plaid_connections_count
    is_savings_or_money_market_account
    total_credit_transactions_amount_10d
    total_debit_transactions_amount_10d
    p50_credit_transactions_amount_28d
    p50_debit_transactions_amount_28d
    p95_credit_transactions_amount_28d
    p95_debit_transactions_amount_28d
    days_with_negative_balance_count_90d
    p90_eod_balance_30d
    p90_eod_balance_60d
    p90_eod_balance_90d
    p10_eod_balance_30d
    p10_eod_balance_60d
    p10_eod_balance_90d
    available_balance
    current_balance
    balance_last_updated
    phone_change_count_28d
    phone_change_count_90d
    email_change_count_28d
    email_change_count_90d
    address_change_count_28d
    address_change_count_90d
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 625

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} unauthorized_transactions_count_7d:"\
  " #{@unauthorized_transactions_count_7d.inspect}, unauthorized_transactions_count_30d:"\
  " #{@unauthorized_transactions_count_30d.inspect}, unauthorized_transactions_count_60d:"\
  " #{@unauthorized_transactions_count_60d.inspect}, unauthorized_transactions_count_90d:"\
  " #{@unauthorized_transactions_count_90d.inspect}, nsf_overdraft_transactions_count_7d:"\
  " #{@nsf_overdraft_transactions_count_7d.inspect}, nsf_overdraft_transactions_count_30d:"\
  " #{@nsf_overdraft_transactions_count_30d.inspect}, nsf_overdraft_transactions_count_60d:"\
  " #{@nsf_overdraft_transactions_count_60d.inspect}, nsf_overdraft_transactions_count_90d:"\
  " #{@nsf_overdraft_transactions_count_90d.inspect}, days_since_first_plaid_connection:"\
  " #{@days_since_first_plaid_connection.inspect}, plaid_connections_count_7d:"\
  " #{@plaid_connections_count_7d.inspect}, plaid_connections_count_30d:"\
  " #{@plaid_connections_count_30d.inspect}, total_plaid_connections_count:"\
  " #{@total_plaid_connections_count.inspect}, is_savings_or_money_market_account:"\
  " #{@is_savings_or_money_market_account.inspect}, total_credit_transactions_amount_10d:"\
  " #{@total_credit_transactions_amount_10d.inspect}, total_debit_transactions_amount_10d:"\
  " #{@total_debit_transactions_amount_10d.inspect}, p50_credit_transactions_amount_28d:"\
  " #{@p50_credit_transactions_amount_28d.inspect}, p50_debit_transactions_amount_28d:"\
  " #{@p50_debit_transactions_amount_28d.inspect}, p95_credit_transactions_amount_28d:"\
  " #{@p95_credit_transactions_amount_28d.inspect}, p95_debit_transactions_amount_28d:"\
  " #{@p95_debit_transactions_amount_28d.inspect}, days_with_negative_balance_count_90d:"\
  " #{@days_with_negative_balance_count_90d.inspect}, p90_eod_balance_30d:"\
  " #{@p90_eod_balance_30d.inspect}, p90_eod_balance_60d: #{@p90_eod_balance_60d.inspect},"\
  " p90_eod_balance_90d: #{@p90_eod_balance_90d.inspect}, p10_eod_balance_30d:"\
  " #{@p10_eod_balance_30d.inspect}, p10_eod_balance_60d: #{@p10_eod_balance_60d.inspect},"\
  " p10_eod_balance_90d: #{@p10_eod_balance_90d.inspect}, available_balance:"\
  " #{@available_balance.inspect}, current_balance: #{@current_balance.inspect},"\
  " balance_last_updated: #{@balance_last_updated.inspect}, phone_change_count_28d:"\
  " #{@phone_change_count_28d.inspect}, phone_change_count_90d:"\
  " #{@phone_change_count_90d.inspect}, email_change_count_28d:"\
  " #{@email_change_count_28d.inspect}, email_change_count_90d:"\
  " #{@email_change_count_90d.inspect}, address_change_count_28d:"\
  " #{@address_change_count_28d.inspect}, address_change_count_90d:"\
  " #{@address_change_count_90d.inspect}, additional_properties: #{@additional_properties}>"
end

#to_custom_balance_last_updatedObject



585
586
587
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 585

def to_custom_balance_last_updated
  DateTimeHelper.to_rfc3339(balance_last_updated)
end

#to_sObject

Provides a human-readable string representation of the object.



590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
# File 'lib/plaid/models/signal_evaluate_core_attributes.rb', line 590

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} unauthorized_transactions_count_7d: #{@unauthorized_transactions_count_7d},"\
  " unauthorized_transactions_count_30d: #{@unauthorized_transactions_count_30d},"\
  " unauthorized_transactions_count_60d: #{@unauthorized_transactions_count_60d},"\
  " unauthorized_transactions_count_90d: #{@unauthorized_transactions_count_90d},"\
  " nsf_overdraft_transactions_count_7d: #{@nsf_overdraft_transactions_count_7d},"\
  " nsf_overdraft_transactions_count_30d: #{@nsf_overdraft_transactions_count_30d},"\
  " nsf_overdraft_transactions_count_60d: #{@nsf_overdraft_transactions_count_60d},"\
  " nsf_overdraft_transactions_count_90d: #{@nsf_overdraft_transactions_count_90d},"\
  " days_since_first_plaid_connection: #{@days_since_first_plaid_connection},"\
  " plaid_connections_count_7d: #{@plaid_connections_count_7d}, plaid_connections_count_30d:"\
  " #{@plaid_connections_count_30d}, total_plaid_connections_count:"\
  " #{@total_plaid_connections_count}, is_savings_or_money_market_account:"\
  " #{@is_savings_or_money_market_account}, total_credit_transactions_amount_10d:"\
  " #{@total_credit_transactions_amount_10d}, total_debit_transactions_amount_10d:"\
  " #{@total_debit_transactions_amount_10d}, p50_credit_transactions_amount_28d:"\
  " #{@p50_credit_transactions_amount_28d}, p50_debit_transactions_amount_28d:"\
  " #{@p50_debit_transactions_amount_28d}, p95_credit_transactions_amount_28d:"\
  " #{@p95_credit_transactions_amount_28d}, p95_debit_transactions_amount_28d:"\
  " #{@p95_debit_transactions_amount_28d}, days_with_negative_balance_count_90d:"\
  " #{@days_with_negative_balance_count_90d}, p90_eod_balance_30d: #{@p90_eod_balance_30d},"\
  " p90_eod_balance_60d: #{@p90_eod_balance_60d}, p90_eod_balance_90d:"\
  " #{@p90_eod_balance_90d}, p10_eod_balance_30d: #{@p10_eod_balance_30d},"\
  " p10_eod_balance_60d: #{@p10_eod_balance_60d}, p10_eod_balance_90d:"\
  " #{@p10_eod_balance_90d}, available_balance: #{@available_balance}, current_balance:"\
  " #{@current_balance}, balance_last_updated: #{@balance_last_updated},"\
  " phone_change_count_28d: #{@phone_change_count_28d}, phone_change_count_90d:"\
  " #{@phone_change_count_90d}, email_change_count_28d: #{@email_change_count_28d},"\
  " email_change_count_90d: #{@email_change_count_90d}, address_change_count_28d:"\
  " #{@address_change_count_28d}, address_change_count_90d: #{@address_change_count_90d},"\
  " additional_properties: #{@additional_properties}>"
end