Class: Plaid::Taxform

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/taxform.rb

Overview

Taxform Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(document_type:, w2: SKIP, additional_properties: nil) ⇒ Taxform

Returns a new instance of Taxform.



40
41
42
43
44
45
46
47
# File 'lib/plaid/models/taxform.rb', line 40

def initialize(document_type:, w2: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @document_type = document_type
  @w2 = w2 unless w2 == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#document_typeString

The type of tax document.

Returns:

  • (String)


14
15
16
# File 'lib/plaid/models/taxform.rb', line 14

def document_type
  @document_type
end

#w2W2

W2 is an object that represents income data taken from a W2 tax document.

Returns:



18
19
20
# File 'lib/plaid/models/taxform.rb', line 18

def w2
  @w2
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/plaid/models/taxform.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  document_type = hash.key?('document_type') ? hash['document_type'] : nil
  w2 = W2.from_hash(hash['w2']) if hash['w2']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Taxform.new(document_type: document_type,
              w2: w2,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/plaid/models/taxform.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['document_type'] = 'document_type'
  @_hash['w2'] = 'w2'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/plaid/models/taxform.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/plaid/models/taxform.rb', line 29

def self.optionals
  %w[
    w2
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/plaid/models/taxform.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} document_type: #{@document_type.inspect}, w2: #{@w2.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/plaid/models/taxform.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} document_type: #{@document_type}, w2: #{@w2}, additional_properties:"\
  " #{@additional_properties}>"
end