Class: Plaid::TaxpayerId

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/taxpayer_id.rb

Overview

TaxpayerId Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id_type: SKIP, last_4_digits: SKIP, additional_properties: nil) ⇒ TaxpayerId

Returns a new instance of TaxpayerId.



44
45
46
47
48
49
50
51
52
# File 'lib/plaid/models/taxpayer_id.rb', line 44

def initialize(id_type: SKIP, last_4_digits: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id_type = id_type unless id_type == SKIP
  @last_4_digits = last_4_digits unless last_4_digits == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#id_typeString

Type of ID, e.g. ‘SSN’

Returns:

  • (String)


14
15
16
# File 'lib/plaid/models/taxpayer_id.rb', line 14

def id_type
  @id_type
end

#last_4_digitsString

Last 4 digits of unique number of ID.

Returns:

  • (String)


18
19
20
# File 'lib/plaid/models/taxpayer_id.rb', line 18

def last_4_digits
  @last_4_digits
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/plaid/models/taxpayer_id.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id_type = hash.key?('id_type') ? hash['id_type'] : SKIP
  last_4_digits = hash.key?('last_4_digits') ? hash['last_4_digits'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TaxpayerId.new(id_type: id_type,
                 last_4_digits: last_4_digits,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/plaid/models/taxpayer_id.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id_type'] = 'id_type'
  @_hash['last_4_digits'] = 'last_4_digits'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
40
41
42
# File 'lib/plaid/models/taxpayer_id.rb', line 37

def self.nullables
  %w[
    id_type
    last_4_digits
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/plaid/models/taxpayer_id.rb', line 29

def self.optionals
  %w[
    id_type
    last_4_digits
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/plaid/models/taxpayer_id.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id_type: #{@id_type.inspect}, last_4_digits: #{@last_4_digits.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/plaid/models/taxpayer_id.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id_type: #{@id_type}, last_4_digits: #{@last_4_digits},"\
  " additional_properties: #{@additional_properties}>"
end