Class: Plaid::TransactionsRemovedWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::TransactionsRemovedWebhook
- Defined in:
- lib/plaid/models/transactions_removed_webhook.rb
Overview
Fired when transaction(s) for an Item are deleted. The deleted transaction IDs are included in the webhook payload. Plaid will typically check for deleted transaction data several times a day.
Instance Attribute Summary collapse
-
#error ⇒ Error
We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#removed_transactions ⇒ Array[String]
An array of ‘transaction_ids` corresponding to the removed transactions.
-
#webhook_code ⇒ String
‘TRANSACTIONS_REMOVED`.
-
#webhook_type ⇒ String
‘TRANSACTIONS`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, removed_transactions:, item_id:, error: SKIP, additional_properties: nil) ⇒ TransactionsRemovedWebhook
constructor
A new instance of TransactionsRemovedWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, removed_transactions:, item_id:, error: SKIP, additional_properties: nil) ⇒ TransactionsRemovedWebhook
Returns a new instance of TransactionsRemovedWebhook.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 61 def initialize(webhook_type:, webhook_code:, removed_transactions:, item_id:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @error = error unless error == SKIP @removed_transactions = removed_transactions @item_id = item_id @additional_properties = additional_properties end |
Instance Attribute Details
#error ⇒ Error
We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`. In general, 200 HTTP codes correspond to success, 40X codes are for developer- or user-related failures, and 50X codes are for Plaid-related issues. Error fields will be `null` if no error has occurred.
28 29 30 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 28 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
36 37 38 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 36 def item_id @item_id end |
#removed_transactions ⇒ Array[String]
An array of ‘transaction_ids` corresponding to the removed transactions
32 33 34 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 32 def removed_transactions @removed_transactions end |
#webhook_code ⇒ String
‘TRANSACTIONS_REMOVED`
20 21 22 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 20 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘TRANSACTIONS`
16 17 18 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 16 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 75 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil removed_transactions = hash.key?('removed_transactions') ? hash['removed_transactions'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsRemovedWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, removed_transactions: removed_transactions, item_id: item_id, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
39 40 41 42 43 44 45 46 47 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 39 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['error'] = 'error' @_hash['removed_transactions'] = 'removed_transactions' @_hash['item_id'] = 'item_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 53 54 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 50 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 117 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, error: #{@error.inspect}, removed_transactions:"\ " #{@removed_transactions.inspect}, item_id: #{@item_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 108 |
# File 'lib/plaid/models/transactions_removed_webhook.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\ " #{@error}, removed_transactions: #{@removed_transactions}, item_id: #{@item_id},"\ " additional_properties: #{@additional_properties}>" end |