Class: Plaid::TransactionsUpdateInvestmentsWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/plaid/models/transactions_update_investments_webhook.rb

Overview

Fired when new or canceled transactions have been detected on an investment account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, item_id:, new_investments_transactions:, canceled_investments_transactions:, error: SKIP, additional_properties: nil) ⇒ TransactionsUpdateInvestmentsWebhook

Returns a new instance of TransactionsUpdateInvestmentsWebhook.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 68

def initialize(webhook_type:, webhook_code:, item_id:,
               new_investments_transactions:,
               canceled_investments_transactions:, error: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @item_id = item_id
  @error = error unless error == SKIP
  @new_investments_transactions = new_investments_transactions
  @canceled_investments_transactions = canceled_investments_transactions
  @additional_properties = additional_properties
end

Instance Attribute Details

#canceled_investments_transactionsFloat

The number of canceled transactions reported since the last time this webhook was fired.

Returns:

  • (Float)


41
42
43
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 41

def canceled_investments_transactions
  @canceled_investments_transactions
end

#errorError

We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`. In general, 200 HTTP codes correspond to success, 40X codes are for developer- or user-related failures, and 50X codes are for Plaid-related issues. Error fields will be `null` if no error has occurred.

Returns:



31
32
33
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 31

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


23
24
25
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 23

def item_id
  @item_id
end

#new_investments_transactionsFloat

The number of new transactions reported since the last time this webhook was fired.

Returns:

  • (Float)


36
37
38
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 36

def new_investments_transactions
  @new_investments_transactions
end

#webhook_codeString

‘DEFAULT_UPDATE`

Returns:

  • (String)


19
20
21
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘INVESTMENTS_TRANSACTIONS`

Returns:

  • (String)


15
16
17
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 85

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  new_investments_transactions =
    hash.key?('new_investments_transactions') ? hash['new_investments_transactions'] : nil
  canceled_investments_transactions =
    hash.key?('canceled_investments_transactions') ? hash['canceled_investments_transactions'] : nil
  error = Error.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionsUpdateInvestmentsWebhook.new(webhook_type: webhook_type,
                                           webhook_code: webhook_code,
                                           item_id: item_id,
                                           new_investments_transactions: new_investments_transactions,
                                           canceled_investments_transactions: canceled_investments_transactions,
                                           error: error,
                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 44

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['error'] = 'error'
  @_hash['new_investments_transactions'] = 'new_investments_transactions'
  @_hash['canceled_investments_transactions'] =
    'canceled_investments_transactions'
  @_hash
end

.nullablesObject

An array for nullable fields



64
65
66
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 64

def self.nullables
  []
end

.optionalsObject

An array for optional fields



57
58
59
60
61
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 57

def self.optionals
  %w[
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



125
126
127
128
129
130
131
132
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 125

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, error: #{@error.inspect},"\
  " new_investments_transactions: #{@new_investments_transactions.inspect},"\
  " canceled_investments_transactions: #{@canceled_investments_transactions.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



116
117
118
119
120
121
122
# File 'lib/plaid/models/transactions_update_investments_webhook.rb', line 116

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, error: #{@error}, new_investments_transactions:"\
  " #{@new_investments_transactions}, canceled_investments_transactions:"\
  " #{@canceled_investments_transactions}, additional_properties: #{@additional_properties}>"
end