Class: Plaid::TransferEventListRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::TransferEventListRequest
- Defined in:
- lib/plaid/models/transfer_event_list_request.rb
Overview
Defines the request schema for ‘/transfer/event/list`
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID to get events for all transactions to/from an account.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#count ⇒ Integer
The maximum number of transfer events to return.
-
#end_date ⇒ DateTime
The end datetime of transfers to list.
-
#event_types ⇒ Array[TransferEventType]
Filter events by event type.
-
#offset ⇒ Integer
The offset into the list of transfer events.
-
#origination_account_id ⇒ String
The origination account ID to get events for transfers from a specific origination account.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#start_date ⇒ DateTime
The start datetime of transfers to list.
-
#transfer_id ⇒ String
Plaid’s unique identifier for a transfer.
-
#transfer_type ⇒ TransferType2
The type of transfer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, start_date: SKIP, end_date: SKIP, transfer_id: SKIP, account_id: SKIP, transfer_type: SKIP, event_types: SKIP, count: 25, offset: 0, origination_account_id: SKIP, additional_properties: nil) ⇒ TransferEventListRequest
constructor
A new instance of TransferEventListRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_end_date ⇒ Object
- #to_custom_start_date ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, start_date: SKIP, end_date: SKIP, transfer_id: SKIP, account_id: SKIP, transfer_type: SKIP, event_types: SKIP, count: 25, offset: 0, origination_account_id: SKIP, additional_properties: nil) ⇒ TransferEventListRequest
Returns a new instance of TransferEventListRequest.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 116 def initialize(client_id: SKIP, secret: SKIP, start_date: SKIP, end_date: SKIP, transfer_id: SKIP, account_id: SKIP, transfer_type: SKIP, event_types: SKIP, count: 25, offset: 0, origination_account_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @start_date = start_date unless start_date == SKIP @end_date = end_date unless end_date == SKIP @transfer_id = transfer_id unless transfer_id == SKIP @account_id = account_id unless account_id == SKIP @transfer_type = transfer_type unless transfer_type == SKIP @event_types = event_types unless event_types == SKIP @count = count unless count == SKIP @offset = offset unless offset == SKIP @origination_account_id = origination_account_id unless origination_account_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The account ID to get events for all transactions to/from an account.
40 41 42 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 40 def account_id @account_id end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 17 def client_id @client_id end |
#count ⇒ Integer
The maximum number of transfer events to return. If the number of events matching the above parameters is greater than ‘count`, the most recent events will be returned.
56 57 58 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 56 def count @count end |
#end_date ⇒ DateTime
The end datetime of transfers to list. This should be in RFC 3339 format (i.e. ‘2019-12-06T22:35:49Z`)
32 33 34 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 32 def end_date @end_date end |
#event_types ⇒ Array[TransferEventType]
Filter events by event type.
50 51 52 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 50 def event_types @event_types end |
#offset ⇒ Integer
The offset into the list of transfer events. When ‘count`=25 and `offset`=0, the first 25 events will be returned. When `count`=25 and `offset`=25, the next 25 bank transfer events will be returned.
62 63 64 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 62 def offset @offset end |
#origination_account_id ⇒ String
The origination account ID to get events for transfers from a specific origination account.
67 68 69 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 67 def origination_account_id @origination_account_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 22 def secret @secret end |
#start_date ⇒ DateTime
The start datetime of transfers to list. This should be in RFC 3339 format (i.e. ‘2019-12-06T22:35:49Z`)
27 28 29 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 27 def start_date @start_date end |
#transfer_id ⇒ String
Plaid’s unique identifier for a transfer.
36 37 38 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 36 def transfer_id @transfer_id end |
#transfer_type ⇒ TransferType2
The type of transfer. This will be either ‘debit` or `credit`. A `debit` indicates a transfer of money into your origination account; a `credit` indicates a transfer of money out of your origination account.
46 47 48 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 46 def transfer_type @transfer_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 138 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP start_date = if hash.key?('start_date') (DateTimeHelper.from_rfc3339(hash['start_date']) if hash['start_date']) else SKIP end end_date = if hash.key?('end_date') (DateTimeHelper.from_rfc3339(hash['end_date']) if hash['end_date']) else SKIP end transfer_id = hash.key?('transfer_id') ? hash['transfer_id'] : SKIP account_id = hash.key?('account_id') ? hash['account_id'] : SKIP transfer_type = hash.key?('transfer_type') ? hash['transfer_type'] : SKIP event_types = hash.key?('event_types') ? hash['event_types'] : SKIP count = hash['count'] ||= 25 offset = hash['offset'] ||= 0 origination_account_id = hash.key?('origination_account_id') ? hash['origination_account_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferEventListRequest.new(client_id: client_id, secret: secret, start_date: start_date, end_date: end_date, transfer_id: transfer_id, account_id: account_id, transfer_type: transfer_type, event_types: event_types, count: count, offset: offset, origination_account_id: origination_account_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 70 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash['transfer_id'] = 'transfer_id' @_hash['account_id'] = 'account_id' @_hash['transfer_type'] = 'transfer_type' @_hash['event_types'] = 'event_types' @_hash['count'] = 'count' @_hash['offset'] = 'offset' @_hash['origination_account_id'] = 'origination_account_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 104 def self.nullables %w[ start_date end_date transfer_id account_id count offset origination_account_id ] end |
.optionals ⇒ Object
An array for optional fields
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 87 def self.optionals %w[ client_id secret start_date end_date transfer_id account_id transfer_type event_types count offset origination_account_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
204 205 206 207 208 209 210 211 212 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 204 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, start_date:"\ " #{@start_date.inspect}, end_date: #{@end_date.inspect}, transfer_id:"\ " #{@transfer_id.inspect}, account_id: #{@account_id.inspect}, transfer_type:"\ " #{@transfer_type.inspect}, event_types: #{@event_types.inspect}, count: #{@count.inspect},"\ " offset: #{@offset.inspect}, origination_account_id: #{@origination_account_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_end_date ⇒ Object
189 190 191 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 189 def to_custom_end_date DateTimeHelper.to_rfc3339(end_date) end |
#to_custom_start_date ⇒ Object
185 186 187 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 185 def to_custom_start_date DateTimeHelper.to_rfc3339(start_date) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
194 195 196 197 198 199 200 201 |
# File 'lib/plaid/models/transfer_event_list_request.rb', line 194 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, start_date: #{@start_date},"\ " end_date: #{@end_date}, transfer_id: #{@transfer_id}, account_id: #{@account_id},"\ " transfer_type: #{@transfer_type}, event_types: #{@event_types}, count: #{@count}, offset:"\ " #{@offset}, origination_account_id: #{@origination_account_id}, additional_properties:"\ " #{@additional_properties}>" end |