Class: Plaid::WebhookVerificationKeyApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/plaid/apis/webhook_verification_key_api.rb

Overview

WebhookVerificationKeyApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from Plaid::BaseApi

Instance Method Details

#webhook_verification_key_get(body) ⇒ ApiResponse

Plaid signs all outgoing webhooks and provides JSON Web Tokens (JWTs) so that you can verify the authenticity of any incoming webhooks to your application. A message signature is included in the ‘Plaid-Verification` header. The `/webhook_verification_key/get` endpoint provides a JSON Web Key (JWK) that can be used to verify a JWT. type description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/plaid/apis/webhook_verification_key_api.rb', line 18

def webhook_verification_key_get(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/webhook_verification_key/get',
                                 Server::DEFAULT)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(WebhookVerificationKeyGetResponse.method(:from_hash))
                .is_api_response(true))
    .execute
end