Class: Plaid::AutomaticallyVerifiedWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::AutomaticallyVerifiedWebhook
- Defined in:
- lib/plaid/models/automatically_verified_webhook.rb
Overview
Fired when an Item is verified via automated micro-deposits. We recommend communicating to your users when this event is received to notify them that their account is verified and ready for use.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ‘account_id` of the account associated with the webhook.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘AUTOMATICALLY_VERIFIED`.
-
#webhook_type ⇒ String
‘AUTH`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, account_id:, item_id:, additional_properties: nil) ⇒ AutomaticallyVerifiedWebhook
constructor
A new instance of AutomaticallyVerifiedWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, account_id:, item_id:, additional_properties: nil) ⇒ AutomaticallyVerifiedWebhook
Returns a new instance of AutomaticallyVerifiedWebhook.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 50 def initialize(webhook_type:, webhook_code:, account_id:, item_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @account_id = account_id @item_id = item_id @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ‘account_id` of the account associated with the webhook
24 25 26 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 24 def account_id @account_id end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
28 29 30 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 28 def item_id @item_id end |
#webhook_code ⇒ String
‘AUTOMATICALLY_VERIFIED`
20 21 22 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 20 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘AUTH`
16 17 18 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 16 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil account_id = hash.key?('account_id') ? hash['account_id'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AutomaticallyVerifiedWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, account_id: account_id, item_id: item_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 38 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['account_id'] = 'account_id' @_hash['item_id'] = 'item_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 41 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 100 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, account_id: #{@account_id.inspect}, item_id:"\ " #{@item_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 |
# File 'lib/plaid/models/automatically_verified_webhook.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, account_id:"\ " #{@account_id}, item_id: #{@item_id}, additional_properties: #{@additional_properties}>" end |