Class: Plaid::BankTransferSweep
- Defined in:
- lib/plaid/models/bank_transfer_sweep.rb
Overview
BankTransferSweep describes a sweep transfer.
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount of the sweep.
-
#created_at ⇒ DateTime
The datetime when the sweep occurred, in RFC 3339 format.
-
#id ⇒ Integer
Identifier of the sweep.
-
#iso_currency_code ⇒ String
The currency of the sweep, e.g.
-
#sweep_account ⇒ BankTransferSweepAccount
The account where the funds are swept to.
-
#transfer_id ⇒ String
Identifier of the sweep transfer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, transfer_id:, created_at:, amount:, iso_currency_code:, sweep_account:, additional_properties: nil) ⇒ BankTransferSweep
constructor
A new instance of BankTransferSweep.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, transfer_id:, created_at:, amount:, iso_currency_code:, sweep_account:, additional_properties: nil) ⇒ BankTransferSweep
Returns a new instance of BankTransferSweep.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 61 def initialize(id:, transfer_id:, created_at:, amount:, iso_currency_code:, sweep_account:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @transfer_id = transfer_id @created_at = created_at @amount = amount @iso_currency_code = iso_currency_code @sweep_account = sweep_account @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ String
The amount of the sweep.
27 28 29 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 27 def amount @amount end |
#created_at ⇒ DateTime
The datetime when the sweep occurred, in RFC 3339 format.
23 24 25 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 23 def created_at @created_at end |
#id ⇒ Integer
Identifier of the sweep.
15 16 17 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 15 def id @id end |
#iso_currency_code ⇒ String
The currency of the sweep, e.g. “USD”.
31 32 33 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 31 def iso_currency_code @iso_currency_code end |
#sweep_account ⇒ BankTransferSweepAccount
The account where the funds are swept to.
35 36 37 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 35 def sweep_account @sweep_account end |
#transfer_id ⇒ String
Identifier of the sweep transfer.
19 20 21 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 19 def transfer_id @transfer_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil transfer_id = hash.key?('transfer_id') ? hash['transfer_id'] : nil created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) end amount = hash.key?('amount') ? hash['amount'] : nil iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil sweep_account = BankTransferSweepAccount.from_hash(hash['sweep_account']) if hash['sweep_account'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankTransferSweep.new(id: id, transfer_id: transfer_id, created_at: created_at, amount: amount, iso_currency_code: iso_currency_code, sweep_account: sweep_account, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['transfer_id'] = 'transfer_id' @_hash['created_at'] = 'created_at' @_hash['amount'] = 'amount' @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['sweep_account'] = 'sweep_account' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 58 59 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 55 def self.nullables %w[ transfer_id ] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 50 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 126 127 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, transfer_id: #{@transfer_id.inspect}, created_at:"\ " #{@created_at.inspect}, amount: #{@amount.inspect}, iso_currency_code:"\ " #{@iso_currency_code.inspect}, sweep_account: #{@sweep_account.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_created_at ⇒ Object
108 109 110 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 108 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
113 114 115 116 117 118 |
# File 'lib/plaid/models/bank_transfer_sweep.rb', line 113 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, transfer_id: #{@transfer_id}, created_at: #{@created_at},"\ " amount: #{@amount}, iso_currency_code: #{@iso_currency_code}, sweep_account:"\ " #{@sweep_account}, additional_properties: #{@additional_properties}>" end |