Class: Plaid::CategoriesApi
- Defined in:
- lib/plaid/apis/categories_api.rb
Overview
CategoriesApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#categories_get(body) ⇒ ApiResponse
Send a request to the ‘/categories/get` endpoint to get detailed information on categories returned by Plaid.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Plaid::BaseApi
Instance Method Details
#categories_get(body) ⇒ ApiResponse
Send a request to the ‘/categories/get` endpoint to get detailed information on categories returned by Plaid. This endpoint does not require authentication.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/plaid/apis/categories_api.rb', line 14 def categories_get(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/categories/get', Server::DEFAULT) .header_param(new_parameter('text/plain', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(APIHelper.method(:json_serialize))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(CategoriesGetResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response.', ErrorErrorException)) .execute end |