Class: Plaid::DepositSwitchAltCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::DepositSwitchAltCreateRequest
- Defined in:
- lib/plaid/models/deposit_switch_alt_create_request.rb
Overview
DepositSwitchAltCreateRequest defines the request schema for ‘/deposit_switch/alt/create`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#country_code ⇒ CountryCode1
ISO-3166-1 alpha-2 country code standard.
-
#options ⇒ DepositSwitchCreateRequestOptions
Options to configure the ‘/deposit_switch/create` request.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#target_account ⇒ DepositSwitchTargetAccount
Your Plaid API ‘secret`.
-
#target_user ⇒ DepositSwitchTargetUser
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(target_account:, target_user:, client_id: SKIP, secret: SKIP, options: SKIP, country_code: SKIP, additional_properties: nil) ⇒ DepositSwitchAltCreateRequest
constructor
A new instance of DepositSwitchAltCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(target_account:, target_user:, client_id: SKIP, secret: SKIP, options: SKIP, country_code: SKIP, additional_properties: nil) ⇒ DepositSwitchAltCreateRequest
Returns a new instance of DepositSwitchAltCreateRequest.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 70 def initialize(target_account:, target_user:, client_id: SKIP, secret: SKIP, options: SKIP, country_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @target_account = target_account @target_user = target_user @options = unless == SKIP @country_code = country_code unless country_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 17 def client_id @client_id end |
#country_code ⇒ CountryCode1
ISO-3166-1 alpha-2 country code standard.
41 42 43 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 41 def country_code @country_code end |
#options ⇒ DepositSwitchCreateRequestOptions
Options to configure the ‘/deposit_switch/create` request. If provided, cannot be `null`.
37 38 39 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 37 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 22 def secret @secret end |
#target_account ⇒ DepositSwitchTargetAccount
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
27 28 29 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 27 def target_account @target_account end |
#target_user ⇒ DepositSwitchTargetUser
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
32 33 34 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 32 def target_user @target_user end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. target_account = DepositSwitchTargetAccount.from_hash(hash['target_account']) if hash['target_account'] target_user = DepositSwitchTargetUser.from_hash(hash['target_user']) if hash['target_user'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = DepositSwitchCreateRequestOptions.from_hash(hash['options']) if hash['options'] country_code = hash.key?('country_code') ? hash['country_code'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DepositSwitchAltCreateRequest.new(target_account: target_account, target_user: target_user, client_id: client_id, secret: secret, options: , country_code: country_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 44 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['target_account'] = 'target_account' @_hash['target_user'] = 'target_user' @_hash['options'] = 'options' @_hash['country_code'] = 'country_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
66 67 68 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 66 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
56 57 58 59 60 61 62 63 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 56 def self.optionals %w[ client_id secret options country_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
124 125 126 127 128 129 130 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 124 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " target_account: #{@target_account.inspect}, target_user: #{@target_user.inspect}, options:"\ " #{@options.inspect}, country_code: #{@country_code.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
116 117 118 119 120 121 |
# File 'lib/plaid/models/deposit_switch_alt_create_request.rb', line 116 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, target_account:"\ " #{@target_account}, target_user: #{@target_user}, options: #{@options}, country_code:"\ " #{@country_code}, additional_properties: #{@additional_properties}>" end |