Class: Plaid::EmployersApi
- Defined in:
- lib/plaid/apis/employers_api.rb
Overview
EmployersApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#employers_search(body) ⇒ ApiResponse
‘/employers/search` allows you the ability to search Plaid’s database of known employers, for use with Deposit Switch.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Plaid::BaseApi
Instance Method Details
#employers_search(body) ⇒ ApiResponse
‘/employers/search` allows you the ability to search Plaid’s database of known employers, for use with Deposit Switch. You can use this endpoint to look up a user’s employer in order to confirm that they are supported. Users with non-supported employers can then be routed out of the Deposit Switch flow. The data in the employer database is currently limited. As the Deposit Switch and Income products progress through their respective beta periods, more employers are being regularly added. Because the employer database is frequently updated, we recommend that you do not cache or store data from this endpoint for more than a day. description here
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/plaid/apis/employers_api.rb', line 22 def employers_search(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/employers/search', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(EmployersSearchResponse.method(:from_hash)) .is_api_response(true)) .execute end |