Class: Plaid::HoldingsDefaultUpdateWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::HoldingsDefaultUpdateWebhook
- Defined in:
- lib/plaid/models/holdings_default_update_webhook.rb
Overview
Fired when new or updated holdings have been detected on an investment account. The webhook typically fires once per day, after market close, in response to any newly added holdings or price changes to existing holdings.
Instance Attribute Summary collapse
-
#error ⇒ Error
We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#new_holdings ⇒ Float
The number of new holdings reported since the last time this webhook was fired.
-
#updated_holdings ⇒ Float
The number of updated holdings reported since the last time this webhook was fired.
-
#webhook_code ⇒ String
‘DEFAULT_UPDATE`.
-
#webhook_type ⇒ String
‘HOLDINGS`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, new_holdings:, updated_holdings:, error: SKIP, additional_properties: nil) ⇒ HoldingsDefaultUpdateWebhook
constructor
A new instance of HoldingsDefaultUpdateWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, new_holdings:, updated_holdings:, error: SKIP, additional_properties: nil) ⇒ HoldingsDefaultUpdateWebhook
Returns a new instance of HoldingsDefaultUpdateWebhook.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 68 def initialize(webhook_type:, webhook_code:, item_id:, new_holdings:, updated_holdings:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @error = error unless error == SKIP @new_holdings = new_holdings @updated_holdings = updated_holdings @additional_properties = additional_properties end |
Instance Attribute Details
#error ⇒ Error
We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`. In general, 200 HTTP codes correspond to success, 40X codes are for developer- or user-related failures, and 50X codes are for Plaid-related issues. Error fields will be `null` if no error has occurred.
32 33 34 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 32 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
24 25 26 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 24 def item_id @item_id end |
#new_holdings ⇒ Float
The number of new holdings reported since the last time this webhook was fired.
37 38 39 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 37 def new_holdings @new_holdings end |
#updated_holdings ⇒ Float
The number of updated holdings reported since the last time this webhook was fired.
42 43 44 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 42 def updated_holdings @updated_holdings end |
#webhook_code ⇒ String
‘DEFAULT_UPDATE`
20 21 22 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 20 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘HOLDINGS`
16 17 18 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 16 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil new_holdings = hash.key?('new_holdings') ? hash['new_holdings'] : nil updated_holdings = hash.key?('updated_holdings') ? hash['updated_holdings'] : nil error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. HoldingsDefaultUpdateWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, new_holdings: new_holdings, updated_holdings: updated_holdings, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['error'] = 'error' @_hash['new_holdings'] = 'new_holdings' @_hash['updated_holdings'] = 'updated_holdings' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 64 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
57 58 59 60 61 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 57 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 126 127 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, error: #{@error.inspect},"\ " new_holdings: #{@new_holdings.inspect}, updated_holdings: #{@updated_holdings.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
113 114 115 116 117 118 |
# File 'lib/plaid/models/holdings_default_update_webhook.rb', line 113 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, error: #{@error}, new_holdings: #{@new_holdings}, updated_holdings:"\ " #{@updated_holdings}, additional_properties: #{@additional_properties}>" end |