Class: Plaid::IncomeApi
Overview
IncomeApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#income_verification_create(body) ⇒ ApiResponse
‘/income/verification/create` begins the income verification process by returning an `income_verification_id`.
-
#income_verification_documents_download(body) ⇒ ApiResponse
‘/income/verification/documents/download` provides the ability to download the source paystub PDF that the end user uploaded via Paystub Import.
-
#income_verification_paystub_get(body) ⇒ ApiResponse
(Deprecated) Retrieve information from a single paystub used for income verification TODO: type description here.
-
#income_verification_paystubs_get(body) ⇒ ApiResponse
‘/income/verification/paystubs/get` returns the information collected from the paystubs that were used to verify an end user’s income.
-
#income_verification_precheck(body) ⇒ ApiResponse
‘/income/verification/precheck` returns whether a given user is supportable by the income product type description here.
-
#income_verification_refresh(body) ⇒ ApiResponse
‘/income/verification/refresh` refreshes a given income verification.
-
#income_verification_summary_get(body) ⇒ ApiResponse
‘/income/verification/summary/get` returns a verification summary for the income that was verified for an end user.
-
#income_verification_taxforms_get(body) ⇒ ApiResponse
‘/income/verification/taxforms/get` returns the information collected from taxforms that were used to verify an end user’s.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from Plaid::BaseApi
Instance Method Details
#income_verification_create(body) ⇒ ApiResponse
‘/income/verification/create` begins the income verification process by returning an `income_verification_id`. You can then provide the `income_verification_id` to `/link/token/create` under the `income_verification` parameter in order to create a Link instance that will prompt the user to go through the income verification flow. Plaid will fire an `INCOME` webhook once the user completes the Payroll Income flow, or when the uploaded documents in the Document Income flow have finished processing. type description here
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/plaid/apis/income_api.rb', line 202 def income_verification_create(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/income/verification/create', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IncomeVerificationCreateResponse.method(:from_hash)) .is_api_response(true)) .execute end |
#income_verification_documents_download(body) ⇒ ApiResponse
‘/income/verification/documents/download` provides the ability to download the source paystub PDF that the end user uploaded via Paystub Import. The response to `/income/verification/documents/download` is a ZIP file in binary data. The `request_id` is returned in the `Plaid-Request-ID` header. For Payroll Income, the most recent file available for download with the payroll provider will also be available from this endpoint. parameter: TODO: type description here
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/plaid/apis/income_api.rb', line 72 def income_verification_documents_download(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/income/verification/documents/download', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:dynamic_deserializer)) .is_api_response(true)) .execute end |
#income_verification_paystub_get(body) ⇒ ApiResponse
(Deprecated) Retrieve information from a single paystub used for income verification TODO: type description here
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/plaid/apis/income_api.rb', line 44 def income_verification_paystub_get(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/income/verification/paystub/get', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IncomeVerificationPaystubGetResponse.method(:from_hash)) .is_api_response(true)) .execute end |
#income_verification_paystubs_get(body) ⇒ ApiResponse
‘/income/verification/paystubs/get` returns the information collected from the paystubs that were used to verify an end user’s income. It can be called once the status of the verification has been set to ‘VERIFICATION_STATUS_PROCESSING_COMPLETE`, as reported by the `INCOME: verification_status` webhook. Attempting to call the endpoint before verification has been completed will result in an error. TODO: type description here
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/plaid/apis/income_api.rb', line 123 def income_verification_paystubs_get(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/income/verification/paystubs/get', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IncomeVerificationPaystubsGetResponse.method(:from_hash)) .is_api_response(true)) .execute end |
#income_verification_precheck(body) ⇒ ApiResponse
‘/income/verification/precheck` returns whether a given user is supportable by the income product type description here
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/plaid/apis/income_api.rb', line 146 def income_verification_precheck(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/income/verification/precheck', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IncomeVerificationPrecheckResponse.method(:from_hash)) .is_api_response(true)) .execute end |
#income_verification_refresh(body) ⇒ ApiResponse
‘/income/verification/refresh` refreshes a given income verification. type description here
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/plaid/apis/income_api.rb', line 93 def income_verification_refresh(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/income/verification/refresh', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IncomeVerificationRefreshResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response.', ErrorErrorException)) .execute end |
#income_verification_summary_get(body) ⇒ ApiResponse
‘/income/verification/summary/get` returns a verification summary for the income that was verified for an end user. It can be called once the status of the verification has been set to `VERIFICATION_STATUS_PROCESSING_COMPLETE`, as reported by the `INCOME: verification_status` webhook. Attempting to call the endpoint before verification has been completed will result in an error. TODO: type description here
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/plaid/apis/income_api.rb', line 173 def income_verification_summary_get(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/income/verification/summary/get', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IncomeVerificationSummaryGetResponse.method(:from_hash)) .is_api_response(true)) .execute end |
#income_verification_taxforms_get(body) ⇒ ApiResponse
‘/income/verification/taxforms/get` returns the information collected from taxforms that were used to verify an end user’s. It can be called once the status of the verification has been set to ‘VERIFICATION_STATUS_PROCESSING_COMPLETE`, as reported by the `INCOME: verification_status` webhook. Attempting to call the endpoint before verification has been completed will result in an error. TODO: type description here
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/plaid/apis/income_api.rb', line 18 def income_verification_taxforms_get(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/income/verification/taxforms/get', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('PLAID-CLIENT-ID', 'PLAID-SECRET', 'Plaid-Version'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(IncomeVerificationTaxformsGetResponse.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response.', ErrorErrorException)) .execute end |