Class: Plaid::IncomeVerificationStatusWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::IncomeVerificationStatusWebhook
- Defined in:
- lib/plaid/models/income_verification_status_webhook.rb
Overview
Fired when the status of an income verification instance has changed. It will typically take several minutes for this webhook to fire after the end user has uploaded their documents in the Document Income flow.
Instance Attribute Summary collapse
-
#income_verification_id ⇒ String
The ‘income_verification_id` of the verification instance whose status is being reported.
-
#verification_status ⇒ String
‘VERIFICATION_STATUS_PROCESSING_COMPLETE`: The income verification status processing has completed.
-
#webhook_code ⇒ String
‘income_verification`.
-
#webhook_type ⇒ String
‘“INCOME”`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, income_verification_id:, verification_status:, additional_properties: nil) ⇒ IncomeVerificationStatusWebhook
constructor
A new instance of IncomeVerificationStatusWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, income_verification_id:, verification_status:, additional_properties: nil) ⇒ IncomeVerificationStatusWebhook
Returns a new instance of IncomeVerificationStatusWebhook.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 61 def initialize(webhook_type:, webhook_code:, income_verification_id:, verification_status:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @income_verification_id = income_verification_id @verification_status = verification_status @additional_properties = additional_properties end |
Instance Attribute Details
#income_verification_id ⇒ String
The ‘income_verification_id` of the verification instance whose status is being reported.
25 26 27 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 25 def income_verification_id @income_verification_id end |
#verification_status ⇒ String
‘VERIFICATION_STATUS_PROCESSING_COMPLETE`: The income verification status processing has completed. `VERIFICATION_STATUS_UPLOAD_ERROR`: An upload error occurred when the end user attempted to upload their verification documentation. `VERIFICATION_STATUS_INVALID_TYPE`: The end user attempted to upload verification documentation in an unsupported file format. `VERIFICATION_STATUS_DOCUMENT_REJECTED`: The documentation uploaded by the end user was recognized as a supported file format, but not recognized as a valid paystub. `VERIFICATION_STATUS_PROCESSING_FAILED`: A failure occurred when attempting to process the verification documentation.
39 40 41 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 39 def verification_status @verification_status end |
#webhook_code ⇒ String
‘income_verification`
20 21 22 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 20 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘“INCOME”`
16 17 18 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 16 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil income_verification_id = hash.key?('income_verification_id') ? hash['income_verification_id'] : nil verification_status = hash.key?('verification_status') ? hash['verification_status'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IncomeVerificationStatusWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, income_verification_id: income_verification_id, verification_status: verification_status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
42 43 44 45 46 47 48 49 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 42 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['income_verification_id'] = 'income_verification_id' @_hash['verification_status'] = 'verification_status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
52 53 54 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 52 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
109 110 111 112 113 114 115 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 109 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, income_verification_id: #{@income_verification_id.inspect},"\ " verification_status: #{@verification_status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
101 102 103 104 105 106 |
# File 'lib/plaid/models/income_verification_status_webhook.rb', line 101 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\ " income_verification_id: #{@income_verification_id}, verification_status:"\ " #{@verification_status}, additional_properties: #{@additional_properties}>" end |