Class: Plaid::InitialUpdateWebhook
- Defined in:
- lib/plaid/models/initial_update_webhook.rb
Overview
Fired when an Item’s initial transaction pull is completed. Once this webhook has been fired, transaction data for the most recent 30 days can be fetched for the Item. If [Account Select v2](plaid.com/docs/link/customization/#account-select) is enabled, this webhook will also be fired if account selections for the Item are updated, with ‘num_transactions` set to the number of net new transactions pulled after the account selection update.
Instance Attribute Summary collapse
-
#error ⇒ String
The error code associated with the webhook.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#new_transactions ⇒ Float
The number of new, unfetched transactions available.
-
#webhook_code ⇒ String
‘INITIAL_UPDATE`.
-
#webhook_type ⇒ String
‘TRANSACTIONS`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, new_transactions:, item_id:, error: SKIP, additional_properties: nil) ⇒ InitialUpdateWebhook
constructor
A new instance of InitialUpdateWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, new_transactions:, item_id:, error: SKIP, additional_properties: nil) ⇒ InitialUpdateWebhook
Returns a new instance of InitialUpdateWebhook.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 63 def initialize(webhook_type:, webhook_code:, new_transactions:, item_id:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @error = error unless error == SKIP @new_transactions = new_transactions @item_id = item_id @additional_properties = additional_properties end |
Instance Attribute Details
#error ⇒ String
The error code associated with the webhook.
28 29 30 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 28 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
36 37 38 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 36 def item_id @item_id end |
#new_transactions ⇒ Float
The number of new, unfetched transactions available.
32 33 34 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 32 def new_transactions @new_transactions end |
#webhook_code ⇒ String
‘INITIAL_UPDATE`
24 25 26 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 24 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘TRANSACTIONS`
20 21 22 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 20 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 77 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil new_transactions = hash.key?('new_transactions') ? hash['new_transactions'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil error = hash.key?('error') ? hash['error'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InitialUpdateWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, new_transactions: new_transactions, item_id: item_id, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
39 40 41 42 43 44 45 46 47 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 39 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['error'] = 'error' @_hash['new_transactions'] = 'new_transactions' @_hash['item_id'] = 'item_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 60 61 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 57 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 53 54 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 50 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 119 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, error: #{@error.inspect}, new_transactions:"\ " #{@new_transactions.inspect}, item_id: #{@item_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 110 |
# File 'lib/plaid/models/initial_update_webhook.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\ " #{@error}, new_transactions: #{@new_transactions}, item_id: #{@item_id},"\ " additional_properties: #{@additional_properties}>" end |