Class: Plaid::ItemGetResponse
- Defined in:
- lib/plaid/models/item_get_response.rb
Overview
ItemGetResponse defines the response schema for ‘/item/get` and `/item/webhook/update`
Instance Attribute Summary collapse
-
#item ⇒ Item
Metadata about the Item.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#status ⇒ ItemStatusNullable
Metadata about the Item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item:, request_id:, status: SKIP, additional_properties: nil) ⇒ ItemGetResponse
constructor
A new instance of ItemGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item:, request_id:, status: SKIP, additional_properties: nil) ⇒ ItemGetResponse
Returns a new instance of ItemGetResponse.
48 49 50 51 52 53 54 55 56 |
# File 'lib/plaid/models/item_get_response.rb', line 48 def initialize(item:, request_id:, status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @item = item @status = status unless status == SKIP @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#item ⇒ Item
Metadata about the Item.
15 16 17 |
# File 'lib/plaid/models/item_get_response.rb', line 15 def item @item end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
25 26 27 |
# File 'lib/plaid/models/item_get_response.rb', line 25 def request_id @request_id end |
#status ⇒ ItemStatusNullable
Metadata about the Item.
19 20 21 |
# File 'lib/plaid/models/item_get_response.rb', line 19 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/plaid/models/item_get_response.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item = Item.from_hash(hash['item']) if hash['item'] request_id = hash.key?('request_id') ? hash['request_id'] : nil status = ItemStatusNullable.from_hash(hash['status']) if hash['status'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemGetResponse.new(item: item, request_id: request_id, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/plaid/models/item_get_response.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['item'] = 'item' @_hash['status'] = 'status' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/plaid/models/item_get_response.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 |
# File 'lib/plaid/models/item_get_response.rb', line 37 def self.optionals %w[ status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/plaid/models/item_get_response.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} item: #{@item.inspect}, status: #{@status.inspect}, request_id:"\ " #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/plaid/models/item_get_response.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} item: #{@item}, status: #{@status}, request_id: #{@request_id},"\ " additional_properties: #{@additional_properties}>" end |