Class: Plaid::ItemProductReadyWebhook
- Defined in:
- lib/plaid/models/item_product_ready_webhook.rb
Overview
Fired once Plaid calculates income from an Item.
Instance Attribute Summary collapse
-
#error ⇒ Error
We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘PRODUCT_READY`.
-
#webhook_type ⇒ String
‘INCOME`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, error: SKIP, additional_properties: nil) ⇒ ItemProductReadyWebhook
constructor
A new instance of ItemProductReadyWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, error: SKIP, additional_properties: nil) ⇒ ItemProductReadyWebhook
Returns a new instance of ItemProductReadyWebhook.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 54 def initialize(webhook_type:, webhook_code:, item_id:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @error = error unless error == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#error ⇒ Error
We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`. In general, 200 HTTP codes correspond to success, 40X codes are for developer- or user-related failures, and 50X codes are for Plaid-related issues. Error fields will be `null` if no error has occurred.
30 31 32 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 30 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
22 23 24 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 22 def item_id @item_id end |
#webhook_code ⇒ String
‘PRODUCT_READY`
18 19 20 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 18 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘INCOME`
14 15 16 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 14 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemProductReadyWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['error'] = 'error' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
43 44 45 46 47 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 43 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, error: #{@error.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/plaid/models/item_product_ready_webhook.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, error: #{@error}, additional_properties: #{@additional_properties}>" end |