Class: Plaid::PaymentInitiationPaymentCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::PaymentInitiationPaymentCreateRequest
- Defined in:
- lib/plaid/models/payment_initiation_payment_create_request.rb
Overview
PaymentInitiationPaymentCreateRequest defines the request schema for ‘/payment_initiation/payment/create`
Instance Attribute Summary collapse
-
#amount ⇒ PaymentAmount
The amount and currency of a payment.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#options ⇒ PaymentOptions
Additional payment options.
-
#recipient_id ⇒ String
The ID of the recipient the payment is for.
-
#reference ⇒ String
A reference for the payment.
-
#schedule ⇒ ExternalPaymentScheduleRequest
The schedule that the payment will be executed on.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(recipient_id:, reference:, amount:, client_id: SKIP, secret: SKIP, schedule: SKIP, options: SKIP, additional_properties: nil) ⇒ PaymentInitiationPaymentCreateRequest
constructor
A new instance of PaymentInitiationPaymentCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(recipient_id:, reference:, amount:, client_id: SKIP, secret: SKIP, schedule: SKIP, options: SKIP, additional_properties: nil) ⇒ PaymentInitiationPaymentCreateRequest
Returns a new instance of PaymentInitiationPaymentCreateRequest.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 76 def initialize(recipient_id:, reference:, amount:, client_id: SKIP, secret: SKIP, schedule: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @recipient_id = recipient_id @reference = reference @amount = amount @schedule = schedule unless schedule == SKIP @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ PaymentAmount
The amount and currency of a payment
36 37 38 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 36 def amount @amount end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 17 def client_id @client_id end |
#options ⇒ PaymentOptions
Additional payment options
46 47 48 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 46 def @options end |
#recipient_id ⇒ String
The ID of the recipient the payment is for.
26 27 28 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 26 def recipient_id @recipient_id end |
#reference ⇒ String
A reference for the payment. This must be an alphanumeric string with at most 18 characters and must not contain any special characters (since not all institutions support them).
32 33 34 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 32 def reference @reference end |
#schedule ⇒ ExternalPaymentScheduleRequest
The schedule that the payment will be executed on. If a schedule is provided, the payment is automatically set up as a standing order. If no schedule is specified, the payment will be executed only once.
42 43 44 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 42 def schedule @schedule end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 93 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. recipient_id = hash.key?('recipient_id') ? hash['recipient_id'] : nil reference = hash.key?('reference') ? hash['reference'] : nil amount = PaymentAmount.from_hash(hash['amount']) if hash['amount'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP schedule = ExternalPaymentScheduleRequest.from_hash(hash['schedule']) if hash['schedule'] = PaymentOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInitiationPaymentCreateRequest.new(recipient_id: recipient_id, reference: reference, amount: amount, client_id: client_id, secret: secret, schedule: schedule, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 49 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['recipient_id'] = 'recipient_id' @_hash['reference'] = 'reference' @_hash['amount'] = 'amount' @_hash['schedule'] = 'schedule' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
72 73 74 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 72 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
62 63 64 65 66 67 68 69 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 62 def self.optionals %w[ client_id secret schedule options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
132 133 134 135 136 137 138 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 132 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, recipient_id:"\ " #{@recipient_id.inspect}, reference: #{@reference.inspect}, amount: #{@amount.inspect},"\ " schedule: #{@schedule.inspect}, options: #{@options.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
124 125 126 127 128 129 |
# File 'lib/plaid/models/payment_initiation_payment_create_request.rb', line 124 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, recipient_id:"\ " #{@recipient_id}, reference: #{@reference}, amount: #{@amount}, schedule: #{@schedule},"\ " options: #{@options}, additional_properties: #{@additional_properties}>" end |