Class: Plaid::SandboxPublicTokenCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::SandboxPublicTokenCreateRequest
- Defined in:
- lib/plaid/models/sandbox_public_token_create_request.rb
Overview
SandboxPublicTokenCreateRequest defines the request schema for ‘/sandbox/public_token/create`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#initial_products ⇒ Array[Products]
The products to initially pull for the Item.
-
#institution_id ⇒ String
The ID of the institution the Item will be associated with.
-
#options ⇒ SandboxPublicTokenCreateRequestOptions
An optional set of options to be used when configuring the Item.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(institution_id:, initial_products:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ SandboxPublicTokenCreateRequest
constructor
A new instance of SandboxPublicTokenCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(institution_id:, initial_products:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ SandboxPublicTokenCreateRequest
Returns a new instance of SandboxPublicTokenCreateRequest.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 63 def initialize(institution_id:, initial_products:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @institution_id = institution_id @initial_products = initial_products @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 17 def client_id @client_id end |
#initial_products ⇒ Array[Products]
The products to initially pull for the Item. May be any products that the specified ‘institution_id` supports. This array may not be empty.
31 32 33 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 31 def initial_products @initial_products end |
#institution_id ⇒ String
The ID of the institution the Item will be associated with
26 27 28 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 26 def institution_id @institution_id end |
#options ⇒ SandboxPublicTokenCreateRequestOptions
An optional set of options to be used when configuring the Item. If specified, must not be ‘null`.
36 37 38 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 36 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 77 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. institution_id = hash.key?('institution_id') ? hash['institution_id'] : nil initial_products = hash.key?('initial_products') ? hash['initial_products'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = SandboxPublicTokenCreateRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxPublicTokenCreateRequest.new(institution_id: institution_id, initial_products: initial_products, client_id: client_id, secret: secret, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
39 40 41 42 43 44 45 46 47 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 39 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['institution_id'] = 'institution_id' @_hash['initial_products'] = 'initial_products' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 53 54 55 56 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 50 def self.optionals %w[ client_id secret options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 120 121 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " institution_id: #{@institution_id.inspect}, initial_products:"\ " #{@initial_products.inspect}, options: #{@options.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
107 108 109 110 111 112 |
# File 'lib/plaid/models/sandbox_public_token_create_request.rb', line 107 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, institution_id:"\ " #{@institution_id}, initial_products: #{@initial_products}, options: #{@options},"\ " additional_properties: #{@additional_properties}>" end |