Class: Plaid::UserPermissionRevokedWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Plaid::UserPermissionRevokedWebhook
- Defined in:
- lib/plaid/models/user_permission_revoked_webhook.rb
Overview
The ‘USER_PERMISSION_REVOKED` webhook is fired to when an end user has used the [my.plaid.com portal](my.plaid.com) to revoke the permission that they previously granted to access an Item. Once access to an Item has been revoked, it cannot be restored. If the user subsequently returns to your application, a new Item must be created for the user.
Instance Attribute Summary collapse
-
#error ⇒ Error
We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘USER_PERMISSION_REVOKED`.
-
#webhook_type ⇒ String
‘ITEM`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, error: SKIP, additional_properties: nil) ⇒ UserPermissionRevokedWebhook
constructor
A new instance of UserPermissionRevokedWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, error: SKIP, additional_properties: nil) ⇒ UserPermissionRevokedWebhook
Returns a new instance of UserPermissionRevokedWebhook.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 58 def initialize(webhook_type:, webhook_code:, item_id:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @error = error unless error == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#error ⇒ Error
We use standard HTTP response codes for success and failure notifications, and our errors are further classified by ‘error_type`. In general, 200 HTTP codes correspond to success, 40X codes are for developer- or user-related failures, and 50X codes are for Plaid-related issues. Error fields will be `null` if no error has occurred.
34 35 36 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 34 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
26 27 28 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 26 def item_id @item_id end |
#webhook_code ⇒ String
‘USER_PERMISSION_REVOKED`
22 23 24 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 22 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘ITEM`
18 19 20 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 18 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserPermissionRevokedWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['error'] = 'error' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
47 48 49 50 51 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 47 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, error: #{@error.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 |
# File 'lib/plaid/models/user_permission_revoked_webhook.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, error: #{@error}, additional_properties: #{@additional_properties}>" end |